@@ -10,6 +10,7 @@ from typing import Dict, Any, Optional, List
 
 import typer
 
+
 # Configuration constants
 class ConfigConstants:
     """Configuration related constants"""
@@ -111,13 +112,13 @@ def load_config(path: Optional[str] = None) -> Dict[str, Any]:
     try:
         with open(config_path, 'r', encoding='utf-8') as f:
             config = json.load(f)
-        typer.echo(f"✅ Configuration loaded from: {config_path}")
+        typer.echo(f" Configuration loaded from: {config_path}")
         return config
     except json.JSONDecodeError as e:
-        typer.echo(f"❌ Invalid JSON in config file: {e}")
+        typer.echo(f" Invalid JSON in config file: {e}")
         return {}
     except Exception as e:
-        typer.echo(f"❌ Failed to load config: {e}")
+        typer.echo(f" Failed to load config: {e}")
         return {}
 
 def save_config(config: Dict[str, Any], path: Optional[str] = None) -> bool:
@@ -134,10 +135,10 @@ def save_config(config: Dict[str, Any], path: Optional[str] = None) -> bool:
         with open(config_path, 'w', encoding='utf-8') as f:
             json.dump(config, f, indent=2, ensure_ascii=False)
         
-        typer.echo(f"✅ Configuration saved to: {config_path}")
+        typer.echo(f" Configuration saved to: {config_path}")
         return True
     except Exception as e:
-        typer.echo(f"❌ Failed to save config: {e}")
+        typer.echo(f" Failed to save config: {e}")
         return False
 
 def _detect_service_type(server_config: Dict[str, Any]) -> str:
@@ -199,7 +200,7 @@ def validate_config(config: Dict[str, Any]) -> bool:
     # 检查根级必需字段
     if "mcpServers" not in config:
         errors.append("Missing 'mcpServers' field")
-        typer.echo("❌ Configuration validation failed:")
+        typer.echo(" Configuration validation failed:")
         for error in errors:
             typer.echo(f"   • {error}")
         return False
@@ -215,12 +216,12 @@ def validate_config(config: Dict[str, Any]) -> bool:
 
     # 输出结果
     if errors:
-        typer.echo("❌ Configuration validation failed:")
+        typer.echo(" Configuration validation failed:")
         for error in errors:
             typer.echo(f"   • {error}")
         return False
     else:
-        typer.echo("✅ Configuration is valid")
+        typer.echo(" Configuration is valid")
         return True
 
 def _format_service_info(name: str, server_config: Dict[str, Any]) -> None:
@@ -294,7 +295,7 @@ def show_config(path: Optional[str] = None):
 
     # 显示服务列表
     servers = config.get("mcpServers", {})
-    typer.echo(f"\n🔧 MCP Services ({len(servers)} configured):")
+    typer.echo(f"\n MCP Services ({len(servers)} configured):")
 
     if not servers:
         typer.echo("   No services configured")
@@ -329,7 +330,7 @@ def init_config(path: Optional[str] = None, force: bool = False, with_examples:
 
     if save_config(config, str(config_path)):
         typer.echo("🎉 Configuration initialized successfully!")
-        typer.echo(f"📁 Location: {config_path}")
+        typer.echo(f" Location: {config_path}")
 
         if with_examples:
             typer.echo("\n💡 Example services have been added. Edit the file to customize them.")
@@ -340,7 +341,7 @@ def add_example_services(path: Optional[str] = None):
     """向现有配置添加示例服务"""
     config = load_config(path)
     if not config:
-        typer.echo("❌ No configuration found. Use 'init' first.")
+        typer.echo(" No configuration found. Use 'init' first.")
         return
 
     examples = get_example_services()
@@ -351,7 +352,7 @@ def add_example_services(path: Optional[str] = None):
         if name not in servers:
             servers[name] = service_config
             added_count += 1
-            typer.echo(f"✅ Added example service: {name}")
+            typer.echo(f" Added example service: {name}")
         else:
             typer.echo(f"⚠️  Service '{name}' already exists, skipping")
 
@@ -375,7 +376,7 @@ def handle_config(action: str, path: Optional[str] = None, **kwargs):
     if action in actions:
         actions[action]()
     else:
-        typer.echo(f"❌ Unknown action: {action}")
+        typer.echo(f" Unknown action: {action}")
         typer.echo(f"Available actions: {', '.join(actions.keys())}")
 
 def _handle_validate(path: Optional[str] = None):
@@ -384,7 +385,7 @@ def _handle_validate(path: Optional[str] = None):
     if config:
         validate_config(config)
     else:
-        typer.echo("❌ No configuration to validate")
+        typer.echo(" No configuration to validate")
 
 def _handle_init(path: Optional[str] = None, **kwargs):
     """处理初始化命令"""
@@ -405,7 +406,7 @@ def _show_config_path(path: Optional[str] = None):
     else:
         config_path = get_default_config_path()
 
-    typer.echo(f"📁 Configuration file path: {config_path}")
+    typer.echo(f" Configuration file path: {config_path}")
     typer.echo(f"📊 Exists: {'Yes' if config_path.exists() else 'No'}")
 
     if config_path.exists():
