@@ -33,30 +33,58 @@ def run_command(
     port: Annotated[int, typer.Option("--port", "-p", help="Port to bind to")] = 18200,
     reload: Annotated[bool, typer.Option("--reload", "-r", help="Enable auto-reload")] = False,
     log_level: Annotated[str, typer.Option("--log-level", "-l", help="Log level")] = "info",
+    prefix: Annotated[str, typer.Option("--prefix", help="URL prefix (e.g., /api/v1)")] = "",  # 🆕 新增
 ):
     """
     Run MCPStore services
 
     Available services:
     - api: Start the MCPStore API server
+
+    Examples:
+
+    # 基本启动（无前缀）
+    mcpstore run api
+
+    # 使用 URL 前缀
+    mcpstore run api --prefix /api/v1
+    # 访问: http://localhost:18200/api/v1/for_store/list_services
+
+    # 开发模式 + 前缀
+    mcpstore run api --reload --prefix /api
     """
     if service == "api":
-        run_api(host=host, port=port, reload=reload, log_level=log_level)
+        run_api(host=host, port=port, reload=reload, log_level=log_level, url_prefix=prefix)
     else:
-        typer.echo(f"❌ Unknown service: {service}")
+        typer.echo(f" Unknown service: {service}")
         typer.echo("Available services: api")
         raise typer.Exit(1)
 
-def run_api(host: str, port: int, reload: bool, log_level: str):
+def run_api(host: str, port: int, reload: bool, log_level: str, url_prefix: str):
     """Start MCPStore API service"""
     try:
         typer.echo("🚀 Starting MCPStore API Server...")
         typer.echo(f"   Host: {host}:{port}")
+
+        if url_prefix:
+            typer.echo(f"   URL Prefix: {url_prefix}")
+            base_url = f"http://{host if host != '0.0.0.0' else 'localhost'}:{port}"
+            typer.echo(f"   Example: {base_url}{url_prefix}/for_store/list_services")
+        else:
+            base_url = f"http://{host if host != '0.0.0.0' else 'localhost'}:{port}"
+            typer.echo(f"   Example: {base_url}/for_store/list_services")
+
         if reload:
             typer.echo("   Mode: Development (auto-reload enabled)")
         typer.echo("   Press Ctrl+C to stop")
         typer.echo()
 
+        # 🆕 启动时传入 URL 前缀配置
+        # 通过环境变量传递给应用工厂
+        import os
+        if url_prefix:
+            os.environ["MCPSTORE_URL_PREFIX"] = url_prefix
+
         # Start API service
         uvicorn.run(
             "mcpstore.scripts.app:app",
@@ -68,7 +96,7 @@ def run_api(host: str, port: int, reload: bool, log_level: str):
     except KeyboardInterrupt:
         typer.echo("\n🛑 Server stopped by user")
     except Exception as e:
-        typer.echo(f"❌ Failed to start server: {e}")
+        typer.echo(f" Failed to start server: {e}")
         raise typer.Exit(1)
 
 @app.command("version")
@@ -127,10 +155,10 @@ def test_command(
         if not success:
             raise typer.Exit(1)
     except ImportError as e:
-        typer.echo(f"❌ Test runner not available: {e}")
+        typer.echo(f" Test runner not available: {e}")
         raise typer.Exit(1)
     except Exception as e:
-        typer.echo(f"❌ Test failed: {e}")
+        typer.echo(f" Test failed: {e}")
         raise typer.Exit(1)
 
 @app.command("config")
@@ -150,10 +178,10 @@ def config_command(
         from mcpstore.cli.config_manager import handle_config
         handle_config(action=action, path=path)
     except ImportError:
-        typer.echo("❌ Config manager not available")
+        typer.echo(" Config manager not available")
         raise typer.Exit(1)
     except Exception as e:
-        typer.echo(f"❌ Config operation failed: {e}")
+        typer.echo(f" Config operation failed: {e}")
         raise typer.Exit(1)
 
 def main():
@@ -164,7 +192,7 @@ def main():
         typer.echo("\n👋 Goodbye!")
         sys.exit(0)
     except Exception as e:
-        typer.echo(f"❌ CLI error: {e}")
+        typer.echo(f" CLI error: {e}")
         sys.exit(1)
 
 if __name__ == "__main__":
