@@ -4,29 +4,15 @@ Core context classes and basic functionality
 """
 
 import logging
-from enum import Enum
-from pathlib import Path
-from typing import Dict, List, Optional, Any, Union, TYPE_CHECKING
+from typing import Dict, List, Optional, Any, TYPE_CHECKING
 
-from mcpstore.core.models.agent import (
-    AgentsSummary, AgentStatistics, AgentServiceSummary
-)
-from mcpstore.core.models.service import (
-    ServiceInfo, ServiceConfigUnion, ServiceConnectionState
-)
-from mcpstore.core.models.tool import ToolExecutionRequest, ToolInfo
-
-from ..utils.async_sync_helper import get_global_helper
-# 旧的认证系统已被新的auth模块替代，保持向后兼容
-# from ..auth_security import get_auth_manager
-from ..cache_performance import get_performance_optimizer
-from ..utils.component_control import get_component_manager
-from ..utils.exceptions import ServiceNotFoundError, InvalidConfigError, DeleteServiceError
-from ..monitoring import MonitoringManager, NetworkEndpoint, SystemResourceInfo
-from ..monitoring.analytics import get_monitoring_manager
-from ..integration.openapi_integration import get_openapi_manager
-from .tool_transformation import get_transformation_manager
 from .agent_service_mapper import AgentServiceMapper
+from .tool_transformation import get_transformation_manager
+from ..performance import get_performance_optimizer
+from ..integration.openapi_integration import get_openapi_manager
+from mcpstore.extensions.monitoring import MonitoringManager
+from mcpstore.extensions.monitoring.analytics import get_monitoring_manager
+from ..utils.async_sync_helper import get_global_helper
 
 # Create logger instance
 logger = logging.getLogger(__name__)
@@ -48,6 +34,8 @@ from .advanced_features import AdvancedFeaturesMixin
 from .resources_prompts import ResourcesPromptsMixin
 from .agent_statistics import AgentStatisticsMixin
 from .service_proxy import ServiceProxy
+from .internal.context_kernel import create_kernel
+from .store_proxy import StoreProxy
 
 class MCPStoreContext(
     ServiceOperationsMixin,
@@ -70,19 +58,16 @@ class MCPStoreContext(
         # Async/sync compatibility helper
         self._sync_helper = get_global_helper()
 
-        # 🔧 修复：初始化等待策略（来自ServiceOperationsMixin）
+        #  修复：初始化等待策略（来自ServiceOperationsMixin）
         from .service_operations import AddServiceWaitStrategy
         self.wait_strategy = AddServiceWaitStrategy()
-        
+
         # 🆕 初始化会话管理（来自SessionManagementMixin）
         SessionManagementMixin.__init__(self)
 
         # New feature manager
         self._transformation_manager = get_transformation_manager()
-        self._component_manager = get_component_manager()
         self._openapi_manager = get_openapi_manager()
-        # 旧认证管理器已被新的auth模块替代
-        # self._auth_manager = get_auth_manager()
         self._performance_optimizer = get_performance_optimizer()
         self._monitoring_manager = get_monitoring_manager()
 
@@ -103,7 +88,7 @@ class MCPStoreContext(
         )
 
         # Agent service name mapper
-        # 🔧 [REFACTOR] global_agent_store不使用服务映射器，因为它使用原始服务名
+        #  [REFACTOR] global_agent_store不使用服务映射器，因为它使用原始服务名
         if agent_id and agent_id != "global_agent_store":
             self._service_mapper = AgentServiceMapper(agent_id)
         else:
@@ -117,10 +102,30 @@ class MCPStoreContext(
         # Keyed by "{service_name}:{tool_name}" -> { flag_name: value }
         self._tool_overrides: Dict[str, Dict[str, Any]] = {}
 
-    def for_langchain(self) -> 'LangChainAdapter':
+        # Phase 1: internal kernel for read paths (no external API change)
+        try:
+            self._kernel = create_kernel(self)
+        except Exception:
+            self._kernel = None
+
+    # ---- Objectified entries ----
+    def for_store(self) -> 'StoreProxy':
+        """Return StoreProxy for objectified store-view."""
+        return StoreProxy(self)
+
+    def find_agent(self, agent_id: str) -> 'AgentProxy':
+        from .agent_proxy import AgentProxy
+        return AgentProxy(self, agent_id)
+
+    def for_langchain(self, response_format: str = "text") -> 'LangChainAdapter':
         """Return a LangChain adapter. If a session is active (within with_session),
         return a session-aware adapter bound to that session; otherwise return the
         standard context adapter.
+
+        Args:
+            response_format: Adapter-only rendering mode for tool outputs. Supported:
+                - "text" (default): Return merged TextContent as string
+                - "content_and_artifact": Return dict {"text": str, "artifacts": list}
         """
         # Avoid top-level import cycles
         from ...adapters.langchain_adapter import LangChainAdapter, SessionAwareLangChainAdapter
@@ -128,9 +133,9 @@ class MCPStoreContext(
         active = getattr(self, "_active_session", None)
         if active is not None and getattr(active, "is_active", False):
             # Implicit session routing: with_session scope auto-binds LangChain tools
-            return SessionAwareLangChainAdapter(self, active)
+            return SessionAwareLangChainAdapter(self, active, response_format=response_format)
 
-        return LangChainAdapter(self)
+        return LangChainAdapter(self, response_format=response_format)
 
     def for_llamaindex(self) -> 'LlamaIndexAdapter':
         """Return a LlamaIndex adapter (FunctionTool) for MCP tools."""
@@ -142,10 +147,13 @@ class MCPStoreContext(
         from ...adapters.crewai_adapter import CrewAIAdapter
         return CrewAIAdapter(self)
 
-    def for_langgraph(self) -> 'LangGraphAdapter':
-        """Return a LangGraph adapter that reuses LangChain tools."""
+    def for_langgraph(self, response_format: str = "text") -> 'LangGraphAdapter':
+        """Return a LangGraph adapter that reuses LangChain tools.
+        Args:
+            response_format: Same as for_langchain(); forwarded to LangChain adapter.
+        """
         from ...adapters.langgraph_adapter import LangGraphAdapter
-        return LangGraphAdapter(self)
+        return LangGraphAdapter(self, response_format=response_format)
 
     def for_autogen(self) -> 'AutoGenAdapter':
         """Return an AutoGen adapter that produces Python functions for registration."""
@@ -163,103 +171,104 @@ class MCPStoreContext(
         return OpenAIAdapter(self)
 
     # === Hub 功能扩展 ===
-    
+
     def hub_services(self) -> 'HubServicesBuilder':
         """
         创建Hub服务打包构建器
-        
+
         将当前上下文中已缓存的服务打包为独立的Hub服务进程。
         基于现有服务数据，不进行新的服务注册。
-        
+
         Returns:
             HubServicesBuilder: Hub服务构建器，支持链式调用
-            
+
         Example:
             # Store级别Hub
             hub = store.for_store().hub_services()\\
                 .with_name("global-hub")\\
                 .with_description("全局服务Hub")\\
                 .build()
-            
-            # Agent级别Hub  
+
+            # Agent级别Hub
             hub = store.for_agent("team1").hub_services()\\
                 .with_name("team-hub")\\
                 .filter_services(category="api")\\
                 .build()
         """
-        from ..hub.builder import HubServicesBuilder
+        from mcpstore.extensions.hub.builder import HubServicesBuilder
         return HubServicesBuilder(self, self._context_type.value, self._agent_id)
-    
+
     def hub_tools(self) -> 'HubToolsBuilder':
         """
         创建Hub工具打包构建器
-        
+
         将工具级别打包为Hub服务。
         注意：此功能在当前版本中为占位实现，后期版本将提供完整功能。
-        
+
         Returns:
             HubToolsBuilder: Hub工具构建器
-            
+
         Raises:
             NotImplementedError: 当前版本未实现此功能
         """
-        from ..hub.builder import HubToolsBuilder
+        from mcpstore.extensions.hub.builder import HubToolsBuilder
         return HubToolsBuilder(self, self._context_type.value, self._agent_id)
-    
-    # === 认证功能扩展 ===
-    # 注意：复杂的认证构建器已移除，现在使用简化的 auth/headers 参数方式
-    # 如需复杂认证配置，请直接使用 FastMCP 的原生API
-    
-    # TODO: 如果需要保留JWT相关功能，可以在后续版本中以更简单的方式实现
 
     def find_service(self, service_name: str) -> 'ServiceProxy':
         """
         查找指定服务并返回服务代理对象
-        
+
         进一步缩小作用域到具体服务，提供该服务的所有操作方法。
-        
+
         Args:
             service_name: 服务名称
-            
+
         Returns:
             ServiceProxy: 服务代理对象，包含该服务的所有操作方法
-            
+
         Example:
             # Store级别使用
             weather_service = store.for_store().find_service('weather')
             weather_service.service_info()      # 获取服务详情
             weather_service.list_tools()       # 列出工具
             weather_service.check_health()     # 检查健康状态
-            
+
             # Agent级别使用
             demo_service = store.for_agent('demo1').find_service('service1')
             demo_service.service_info()        # 获取服务详情
             demo_service.restart_service()     # 重启服务
         """
         from .service_proxy import ServiceProxy
+        try:
+            effective = service_name
+            if self._context_type == ContextType.AGENT and getattr(self, '_service_mapper', None):
+                effective = self._service_mapper.to_global_name(service_name)
+            logger.info(f"[FIND_SERVICE] context={self._context_type.name} agent_id={self._agent_id} input='{service_name}' effective='{effective}'")
+        except Exception as e:
+            logger.warning(f"[FIND_SERVICE] mapping_info_failed name='{service_name}' error={e}")
         return ServiceProxy(self, service_name)
 
     def find_tool(self, tool_name: str) -> 'ToolProxy':
         """
         查找指定工具并返回工具代理对象
-        
+
         在当前上下文范围内查找工具：
         - Store 上下文: 搜索全局所有服务的工具
         - Agent 上下文: 搜索该 Agent 的所有服务的工具
-        
+
         Args:
             tool_name: 工具名称
-            
+
         Returns:
             ToolProxy: 工具代理对象，包含该工具的所有操作方法
-            
+
         Example:
             # Store级别使用
             weather_tool = store.for_store().find_tool('get_current_weather')
             weather_tool.tool_info()        # 获取工具详情
             weather_tool.call_tool({...})   # 调用工具
             weather_tool.usage_stats()      # 使用统计
-            
+
             # Agent级别使用
             demo_tool = store.for_agent('demo1').find_tool('search_tool')
             demo_tool.tool_info()           # 获取工具详情
@@ -286,20 +295,35 @@ class MCPStoreContext(
         """
         return self._store._unified_config
 
+    def setup_config(self) -> Dict[str, Any]:
+        """Return a read-only snapshot of setup-time configuration.
+        This reflects the effective configuration used during MCPStore.setup_store().
+        """
+        from copy import deepcopy
+        snap = getattr(self._store, "_setup_snapshot", None)
+        if isinstance(snap, dict):
+            return deepcopy(snap)
+        # Fallback minimal snapshot
+        try:
+            lvl = logging.getLogger().getEffectiveLevel()
+            level_name = (
+                "DEBUG" if lvl <= logging.DEBUG else
+                "INFO" if lvl <= logging.INFO else
+                "WARNING" if lvl <= logging.WARNING else
+                "ERROR" if lvl <= logging.ERROR else
+                "CRITICAL" if lvl <= logging.CRITICAL else "OFF"
+            )
+        except Exception:
+            level_name = "OFF"
+        return {
+            "mcp_json": getattr(self._store.config, "json_path", None),
+            "debug_level": level_name,
+            "external_db": {},
+            "static_config": {}
+        }
+
     # === Monitoring and statistics functionality ===
 
-    async def check_network_endpoints(self, endpoints: List[Dict[str, str]]) -> List[NetworkEndpoint]:
-        """Check network endpoint status"""
-        return await self._monitoring.check_network_endpoints(endpoints)
-
-    def get_system_resource_info(self) -> SystemResourceInfo:
-        """Get system resource information"""
-        return self._monitoring.get_system_resource_info()
-
-    async def get_system_resource_info_async(self) -> SystemResourceInfo:
-        """Asynchronously get system resource information"""
-        return self.get_system_resource_info()
-
     def record_api_call(self, response_time: float):
         """Record API call"""
         self._monitoring.record_api_call(response_time)
@@ -321,7 +345,7 @@ class MCPStoreContext(
         return self.get_tool_records(limit)
 
     # === Internal helper methods ===
-    
+
     def _tool_override_key(self, service_name: str, tool_name: str) -> str:
         """Compose stable key for tool overrides."""
         service_safe = service_name or ""
@@ -364,7 +388,20 @@ class MCPStoreContext(
                 services = self._store.for_store().list_services()
             else:
                 services = self._store.for_agent(self._agent_id).list_services()
-            return [service.name for service in services]
+            names: List[str] = []
+            for service in services or []:
+                if isinstance(service, dict):
+                    name = service.get("name")
+                    if isinstance(name, str):
+                        names.append(name)
+                else:
+                    try:
+                        n = getattr(service, "name", None)
+                        if isinstance(n, str):
+                            names.append(n)
+                    except Exception:
+                        pass
+            return names
         except Exception:
             return []
 
@@ -402,12 +439,12 @@ class MCPStoreContext(
                 for service_key, entry in all_entries.items():
                     if entry.client_id == client_id:
                         entries_to_remove.append(service_key)
-                
+
                 # Remove entries
                 for service_key in entries_to_remove:
                     reconnection_manager.remove_service(service_key)
                     logger.debug(f"Removed reconnection entry for {service_key}")
-                    
+
         except Exception as e:
             logger.warning(f"Failed to cleanup reconnection queue for client {client_id}: {e}")
 
