@@ -16,29 +16,47 @@ logger = logging.getLogger(__name__)
 
 class UpdateServiceAuthHelper:
     """更新服务认证助手 - 明确的服务名，避免状态混乱"""
-    
+
     def __init__(self, context: 'MCPStoreContext', service_name: str, config: Dict[str, Any] = None):
         self._context = context
         self._service_name = service_name  # 🎯 明确的服务名，不会混乱
         self._config = config.copy() if config else {}
-    
+
     def bearer_auth(self, auth: str) -> 'MCPStoreContext':
-        """为指定服务更新 Bearer Token 认证"""
-        self._config["auth"] = auth
+        """为指定服务更新 Bearer Token 认证（兼容历史）"""
+        # 统一标准化为 Authorization 头
+        if "headers" not in self._config:
+            self._config["headers"] = {}
+        self._config["headers"]["Authorization"] = f"Bearer {auth}"
         return self._execute_update()
-    
+
+    def token(self, token: str) -> 'MCPStoreContext':
+        """推荐：设置 Bearer Token（等价于 bearer_auth）"""
+        if "headers" not in self._config:
+            self._config["headers"] = {}
+        self._config["headers"]["Authorization"] = f"Bearer {token}"
+        return self._execute_update()
+
+    def api_key(self, api_key: str) -> 'MCPStoreContext':
+        """推荐：设置 API Key（标准化为 X-API-Key）"""
+        if "headers" not in self._config:
+            self._config["headers"] = {}
+        self._config["headers"]["X-API-Key"] = api_key
+        return self._execute_update()
+
     def custom_headers(self, headers: Dict[str, str]) -> 'MCPStoreContext':
-        """为指定服务更新自定义请求头"""
+        """为指定服务更新自定义请求头（显式覆盖）"""
         if "headers" not in self._config:
             self._config["headers"] = {}
         self._config["headers"].update(headers)
         return self._execute_update()
-    
+
     def _execute_update(self) -> 'MCPStoreContext':
         """执行更新服务"""
         self._context._sync_helper.run_async(
             self._context.update_service_async(self._service_name, self._config),
-            timeout=60.0
+            timeout=60.0,
+            force_background=True
         )
         return self._context
 
@@ -52,7 +70,7 @@ class ServiceManagementMixin:
         - store上下文：聚合 global_agent_store 下所有 client_id 的服务健康状态
         - agent上下文：聚合 agent_id 下所有 client_id 的服务健康状态
         """
-        return self._sync_helper.run_async(self.check_services_async())
+        return self._sync_helper.run_async(self.check_services_async(), force_background=True)
 
     async def check_services_async(self) -> dict:
         """
@@ -74,7 +92,7 @@ class ServiceManagementMixin:
         - store上下文：在 global_agent_store 下的所有 client 中查找服务
         - agent上下文：在指定 agent_id 下的所有 client 中查找服务
         """
-        return self._sync_helper.run_async(self.get_service_info_async(name))
+        return self._sync_helper.run_async(self.get_service_info_async(name), force_background=True)
 
     async def get_service_info_async(self, name: str) -> Any:
         """
@@ -86,58 +104,61 @@ class ServiceManagementMixin:
             return {}
 
         if self._context_type == ContextType.STORE:
-            logger.info(f"[get_service_info] STORE模式-在global_agent_store中查找服务: {name}")
+            logger.debug(f"STORE mode - searching service in global_agent_store: {name}")
             return await self._store.get_service_info(name)
         elif self._context_type == ContextType.AGENT:
             # Agent模式：将名称原样交给 Store 层处理，Store 负责本地名/全局名的鲁棒解析
-            logger.info(f"[get_service_info] AGENT模式-在agent({self._agent_id})中查找服务: {name}")
+            logger.debug(f"AGENT mode - searching service in agent({self._agent_id}): {name}")
             return await self._store.get_service_info(name, self._agent_id)
         else:
             logger.error(f"[get_service_info] 未知上下文类型: {self._context_type}")
             return {}
 
-    def update_service(self, 
-                      name: str, 
+    def update_service(self,
+                      name: str,
                       config: Union[Dict[str, Any], None] = None,
-                      # 🆕 与 FastMCP 对齐
-                      auth: Optional[str] = None,
+                      # 🆕 与用户用法对齐
+                      auth: Optional[str] = None,            # 兼容历史：等价于 token
+                      token: Optional[str] = None,           # 推荐：Bearer Token
+                      api_key: Optional[str] = None,         # 推荐：API Key
                       headers: Optional[Dict[str, str]] = None) -> Union['MCPStoreContext', 'UpdateServiceAuthHelper']:
         """
-        更新服务配置，支持安全的链式认证
-        
+        更新服务配置，支持安全的链式认证与凭证轮换（合并更新，不会破坏原有关键字段）
+
         Args:
             name: 服务名称（明确指定，不会混乱）
-            config: 新的服务配置
-            auth: Bearer token，如果提供则立即执行
-            headers: 自定义请求头，如果提供则立即执行
-            
+            config: 新的服务配置（可选，按“补丁”合并语义处理）
+            auth/token: Bearer token（两者等价；优先使用 token）
+            api_key: API Key（统一标准化为 X-API-Key 头）
+            headers: 自定义请求头（显式传入的键优先级最高）
+
         Returns:
             如果有配置或认证参数：立即执行更新，返回 MCPStoreContext
             如果什么都没有：返回 UpdateServiceAuthHelper 支持链式配置
         """
-        
+
         if config is not None:
-            # 有配置参数：立即执行更新（保持向后兼容）
-            if auth is not None or headers is not None:
-                # 配置 + 认证：合并后执行
-                final_config = self._apply_auth_to_update_config(config, auth, headers)
+            # 有配置参数：立即执行更新（与认证参数合并，并采用“补丁合并”语义）
+            if any([auth, token, api_key, headers]):
+                final_config = self._apply_auth_to_update_config(config, auth, token, api_key, headers)
             else:
-                # 纯配置：直接执行
                 final_config = config
-                
+
             self._sync_helper.run_async(
                 self.update_service_async(name, final_config),
-                timeout=60.0
+                timeout=60.0,
+                force_background=True
             )
             return self
         else:
             # 没有配置参数：
-            if auth is not None or headers is not None:
-                # 纯认证：立即执行
-                final_config = self._apply_auth_to_update_config({}, auth, headers)
+            if any([auth, token, api_key, headers]):
+                # 纯认证：立即执行（也走补丁合并语义）
+                final_config = self._apply_auth_to_update_config({}, auth, token, api_key, headers)
                 self._sync_helper.run_async(
                     self.update_service_async(name, final_config),
-                    timeout=60.0
+                    timeout=60.0,
+                    force_background=True
                 )
                 return self
             else:
@@ -146,26 +167,46 @@ class ServiceManagementMixin:
 
     async def update_service_async(self, name: str, config: Dict[str, Any]) -> bool:
         """
-        更新服务配置（异步版本）- 完全替换配置
+        更新服务配置（异步版本）- 合并更新（不会破坏未提供的关键字段）
 
         Args:
             name: 服务名称
-            config: 新的服务配置
+            config: 新的服务配置（作为补丁）
 
         Returns:
             bool: 更新是否成功
         """
         try:
-            if self._context_type == ContextType.STORE:
-                # Store级别：直接更新mcp.json中的服务配置
-                current_config = self._store.config.load_config()
-                if name not in current_config.get("mcpServers", {}):
-                    logger.error(f"Service {name} not found in store configuration")
-                    return False
+            #  内部：简单的深度合并（仅对字典执行一层合并；headers 为字典则键级覆盖）
+            def _deep_merge(base: Dict[str, Any], patch: Dict[str, Any]) -> Dict[str, Any]:
+                result = dict(base or {})
+                for k, v in (patch or {}).items():
+                    if isinstance(v, dict) and isinstance(result.get(k), dict):
+                        merged = dict(result.get(k) or {})
+                        merged.update(v)
+                        result[k] = merged
+                    else:
+                        result[k] = v
+                return result
 
-                # 完全替换配置
-                current_config["mcpServers"][name] = config
-                success = self._store.config.save_config(current_config)
+            if self._context_type == ContextType.STORE:
+                # Store级别：使用原子更新，避免读改写竞态
+                from mcpstore.core.configuration.config_write_service import ConfigWriteService
+                cws = ConfigWriteService()
+                def _mutator(cfg: Dict[str, Any]) -> Dict[str, Any]:
+                    servers = dict(cfg.get("mcpServers", {}))
+                    if name not in servers:
+                        raise KeyError(f"Service {name} not found in store configuration")
+                    existing = dict(servers.get(name) or {})
+                    merged = _deep_merge(existing, config)
+                    servers[name] = merged
+                    cfg["mcpServers"] = servers
+                    return cfg
+                try:
+                    success = cws.atomic_update(self._store.config.json_path, _mutator)
+                except KeyError as e:
+                    logger.error(str(e))
+                    return False
 
                 if success:
                     # 触发重新注册
@@ -179,14 +220,23 @@ class ServiceManagementMixin:
                 if self._service_mapper:
                     global_name = self._service_mapper.to_global_name(name)
 
-                current_config = self._store.config.load_config()
-                if global_name not in current_config.get("mcpServers", {}):
-                    logger.error(f"Service {global_name} not found in store configuration (agent mode)")
+                from mcpstore.core.configuration.config_write_service import ConfigWriteService
+                cws = ConfigWriteService()
+                def _mutator(cfg: Dict[str, Any]) -> Dict[str, Any]:
+                    servers = dict(cfg.get("mcpServers", {}))
+                    if global_name not in servers:
+                        raise KeyError(f"Service {global_name} not found in store configuration (agent mode)")
+                    existing = dict(servers.get(global_name) or {})
+                    merged = _deep_merge(existing, config)
+                    servers[global_name] = merged
+                    cfg["mcpServers"] = servers
+                    return cfg
+                try:
+                    success = cws.atomic_update(self._store.config.json_path, _mutator)
+                except KeyError as e:
+                    logger.error(str(e))
                     return False
 
-                current_config["mcpServers"][global_name] = config
-                success = self._store.config.save_config(current_config)
-
                 if success and hasattr(self._store.orchestrator, 'sync_manager') and self._store.orchestrator.sync_manager:
                     await self._store.orchestrator.sync_manager.sync_global_agent_store_from_mcp_json()
 
@@ -196,7 +246,8 @@ class ServiceManagementMixin:
                     global_agent = self._store.client_manager.global_agent_store_id
                     metadata = self._store.registry.get_service_metadata(global_agent, global_name)
                     if metadata:
-                        metadata.service_config = config
+                        # 将变更合并到缓存元数据中
+                        metadata.service_config = _deep_merge(metadata.service_config or {}, config)
                         self._store.registry.set_service_metadata(global_agent, global_name, metadata)
                 except Exception as _:
                     pass
@@ -217,7 +268,7 @@ class ServiceManagementMixin:
         Returns:
             bool: 更新是否成功
         """
-        return self._sync_helper.run_async(self.patch_service_async(name, updates), timeout=60.0)
+        return self._sync_helper.run_async(self.patch_service_async(name, updates), timeout=60.0, force_background=True)
 
     async def patch_service_async(self, name: str, updates: Dict[str, Any]) -> bool:
         """
@@ -232,18 +283,24 @@ class ServiceManagementMixin:
         """
         try:
             if self._context_type == ContextType.STORE:
-                # Store级别：增量更新mcp.json中的服务配置
-                current_config = self._store.config.load_config()
-                if name not in current_config.get("mcpServers", {}):
-                    logger.error(f"Service {name} not found in store configuration")
+                # Store级别：使用原子增量更新
+                from mcpstore.core.configuration.config_write_service import ConfigWriteService
+                cws = ConfigWriteService()
+                def _mutator(cfg: Dict[str, Any]) -> Dict[str, Any]:
+                    servers = dict(cfg.get("mcpServers", {}))
+                    if name not in servers:
+                        raise KeyError(f"Service {name} not found in store configuration")
+                    merged = dict(servers[name])
+                    merged.update(updates)
+                    servers[name] = merged
+                    cfg["mcpServers"] = servers
+                    return cfg
+                try:
+                    success = cws.atomic_update(self._store.config.json_path, _mutator)
+                except KeyError as e:
+                    logger.error(str(e))
                     return False
 
-                # 增量更新配置
-                service_config = current_config["mcpServers"][name]
-                service_config.update(updates)
-
-                success = self._store.config.save_config(current_config)
-
                 if success:
                     # 触发重新注册
                     if hasattr(self._store.orchestrator, 'sync_manager') and self._store.orchestrator.sync_manager:
@@ -255,16 +312,23 @@ class ServiceManagementMixin:
                 global_name = name
                 if self._service_mapper:
                     global_name = self._service_mapper.to_global_name(name)
-
-                current_config = self._store.config.load_config()
-                if global_name not in current_config.get("mcpServers", {}):
-                    logger.error(f"Service {global_name} not found in store configuration (agent mode)")
+                from mcpstore.core.configuration.config_write_service import ConfigWriteService
+                cws = ConfigWriteService()
+                def _mutator(cfg: Dict[str, Any]) -> Dict[str, Any]:
+                    servers = dict(cfg.get("mcpServers", {}))
+                    if global_name not in servers:
+                        raise KeyError(f"Service {global_name} not found in store configuration (agent mode)")
+                    merged = dict(servers[global_name])
+                    merged.update(updates)
+                    servers[global_name] = merged
+                    cfg["mcpServers"] = servers
+                    return cfg
+                try:
+                    success = cws.atomic_update(self._store.config.json_path, _mutator)
+                except KeyError as e:
+                    logger.error(str(e))
                     return False
 
-                # 增量更新配置
-                current_config["mcpServers"][global_name].update(updates)
-                success = self._store.config.save_config(current_config)
-
                 if success and hasattr(self._store.orchestrator, 'sync_manager') and self._store.orchestrator.sync_manager:
                     await self._store.orchestrator.sync_manager.sync_global_agent_store_from_mcp_json()
 
@@ -294,7 +358,7 @@ class ServiceManagementMixin:
         Returns:
             bool: 删除是否成功
         """
-        return self._sync_helper.run_async(self.delete_service_async(name), timeout=60.0)
+        return self._sync_helper.run_async(self.delete_service_async(name), timeout=60.0, force_background=True)
 
     async def delete_service_async(self, name: str) -> bool:
         """
@@ -377,7 +441,7 @@ class ServiceManagementMixin:
                 - "all": 重置所有缓存和所有JSON文件（默认）
                 - "global_agent_store": 只重置global_agent_store
         """
-        return self._sync_helper.run_async(self.reset_config_async(scope), timeout=60.0)
+        return self._sync_helper.run_async(self.reset_config_async(scope), timeout=60.0, force_background=True)
 
     async def reset_config_async(self, scope: str = "all") -> bool:
         """
@@ -405,7 +469,7 @@ class ServiceManagementMixin:
         """Store级别重置配置的内部实现"""
         try:
             if scope == "all":
-                logger.info(" Store级别：重置所有缓存和所有JSON文件")
+                logger.debug("Store level: resetting all caches and JSON files")
 
                 # 1. 清空所有缓存
                 self._store.registry.agent_clients.clear()
@@ -419,14 +483,24 @@ class ServiceManagementMixin:
                 self._store.registry.service_metadata.clear()
                 self._store.registry.service_to_client.clear()
 
-                # 2. 重置mcp.json文件
+                # 2. 重置mcp.json文件（使用 UnifiedConfigManager 自动刷新缓存）
                 default_config = {"mcpServers": {}}
-                mcp_success = self._store.config.save_config(default_config)
+                mcp_success = self._store._unified_config.update_mcp_config(default_config)
 
                 # 3. 单源模式：不再维护分片映射文件
-                logger.info("Single-source mode: skip shard mapping files (agent_clients/client_services)")
+                logger.debug("Single-source mode: skip shard mapping files (agent_clients/client_services)")
 
-                logger.info(" Store级别：所有配置重置完成")
+                # 4. 触发快照更新（强一致）
+                try:
+                    gid = self._store.client_manager.global_agent_store_id
+                    self._store.registry.tools_changed(gid, aggressive=True)
+                except Exception:
+                    try:
+                        self._store.registry.mark_tools_snapshot_dirty()
+                    except Exception:
+                        pass
+
+                logger.debug("Store level: all configuration reset completed")
                 return mcp_success
 
             elif scope == "global_agent_store":
@@ -436,12 +510,22 @@ class ServiceManagementMixin:
                 global_agent_store_id = self._store.client_manager.global_agent_store_id
                 self._store.registry.clear(global_agent_store_id)
 
-                # 2. 清空mcp.json文件
+                # 2. 清空mcp.json文件（使用 UnifiedConfigManager 自动刷新缓存）
                 default_config = {"mcpServers": {}}
-                mcp_success = self._store.config.save_config(default_config)
+                mcp_success = self._store._unified_config.update_mcp_config(default_config)
 
                 # 3. 单源模式：不再维护分片映射文件
-                logger.info("Single-source mode: skip shard mapping files (agent_clients/client_services)")
+                logger.debug("Single-source mode: skip shard mapping files (agent_clients/client_services)")
+
+                # 4. 触发快照更新（强一致）
+                try:
+                    gid = self._store.client_manager.global_agent_store_id
+                    self._store.registry.tools_changed(gid, aggressive=True)
+                except Exception:
+                    try:
+                        self._store.registry.mark_tools_snapshot_dirty()
+                    except Exception:
+                        pass
 
                 logger.info(" Store级别：global_agent_store重置完成")
                 return mcp_success
@@ -484,7 +568,7 @@ class ServiceManagementMixin:
         Returns:
             Dict: 配置信息字典
         """
-        return self._sync_helper.run_async(self.show_config_async(scope), timeout=60.0)
+        return self._sync_helper.run_async(self.show_config_async(scope), timeout=60.0, force_background=True)
 
     async def show_config_async(self, scope: str = "all") -> Dict[str, Any]:
         """
@@ -662,7 +746,7 @@ class ServiceManagementMixin:
         Returns:
             Dict: 删除结果
         """
-        return self._sync_helper.run_async(self.delete_config_async(client_id_or_service_name), timeout=60.0)
+        return self._sync_helper.run_async(self.delete_config_async(client_id_or_service_name), timeout=60.0, force_background=True)
 
     async def delete_config_async(self, client_id_or_service_name: str) -> Dict[str, Any]:
         """
@@ -704,7 +788,7 @@ class ServiceManagementMixin:
         Returns:
             Dict: 更新结果
         """
-        return self._sync_helper.run_async(self.update_config_async(client_id_or_service_name, new_config), timeout=60.0)
+        return self._sync_helper.run_async(self.update_config_async(client_id_or_service_name, new_config), timeout=60.0, force_background=True)
 
     async def update_config_async(self, client_id_or_service_name: str, new_config: Dict[str, Any]) -> Dict[str, Any]:
         """
@@ -778,18 +862,18 @@ class ServiceManagementMixin:
             # 检查client_id是否存在于agent的映射中
             agent_clients = self._store.registry.get_agent_clients_from_cache(agent_id)
             if client_id not in agent_clients:
-                logger.debug(f"🔍 [VALIDATE_MAPPING] client_id '{client_id}' not found in agent '{agent_id}' clients")
+                logger.debug(f" [VALIDATE_MAPPING] client_id '{client_id}' not found in agent '{agent_id}' clients")
                 return False
 
             # 检查service_name是否存在于Registry中
             existing_client_id = self._store.registry.get_service_client_id(agent_id, service_name)
             if existing_client_id != client_id:
-                logger.debug(f"🔍 [VALIDATE_MAPPING] service '{service_name}' maps to different client_id: expected={client_id}, actual={existing_client_id}")
+                logger.debug(f" [VALIDATE_MAPPING] service '{service_name}' maps to different client_id: expected={client_id}, actual={existing_client_id}")
                 return False
 
             return True
         except Exception as e:
-            logger.debug(f"🔍 [VALIDATE_MAPPING] 验证失败: {e}")
+            logger.debug(f" [VALIDATE_MAPPING] 验证失败: {e}")
             return False
 
     def _resolve_client_id(self, client_id_or_service_name: str, agent_id: str) -> Tuple[str, str]:
@@ -883,12 +967,10 @@ class ServiceManagementMixin:
                 logger.warning(f"Service {service_name} not found in registry, but continuing with cleanup")
 
             # 事务性删除：先删除文件配置，再删除缓存
-            # 1. 从mcp.json中删除服务配置
-            current_config = self._store.config.load_config()
-            if "mcpServers" in current_config and service_name in current_config["mcpServers"]:
-                del current_config["mcpServers"][service_name]
-                self._store.config.save_config(current_config)
-                logger.info(f"🗑️ 已从mcp.json删除服务: {service_name}")
+            # 1. 从mcp.json中删除服务配置（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self._store._unified_config.remove_service_config(service_name)
+            if success:
+                logger.info(f"🗑️ 已从mcp.json删除服务: {service_name}，缓存已同步")
 
             # 2. 从缓存中删除服务（包括工具和会话）
             self._store.registry.remove_service(global_agent_store_id, service_name)
@@ -907,6 +989,15 @@ class ServiceManagementMixin:
 
             logger.info(f" Store级别：配置删除完成 {service_name}")
 
+            # 触发快照更新（强一致）
+            try:
+                self._store.registry.tools_changed(global_agent_store_id, aggressive=True)
+            except Exception:
+                try:
+                    self._store.registry.mark_tools_snapshot_dirty()
+                except Exception:
+                    pass
+
             return {
                 "success": True,
                 "message": f"Service '{service_name}' deleted successfully",
@@ -955,6 +1046,16 @@ class ServiceManagementMixin:
 
             logger.info(f" Agent级别：配置删除完成 {service_name}")
 
+            # 触发快照更新（强一致）
+            try:
+                gid = self._store.client_manager.global_agent_store_id
+                self._store.registry.tools_changed(gid, aggressive=True)
+            except Exception:
+                try:
+                    self._store.registry.mark_tools_snapshot_dirty()
+                except Exception:
+                    pass
+
             return {
                 "success": True,
                 "message": f"Service '{service_name}' deleted successfully from agent '{self._agent_id}'",
@@ -1073,12 +1174,10 @@ class ServiceManagementMixin:
                 metadata.state_entered_time = datetime.now()
                 self._store.registry.set_service_metadata(global_agent_store_id, service_name, metadata)
 
-            # 4. 更新mcp.json文件
-            current_config = self._store.config.load_config()
-            if "mcpServers" not in current_config:
-                current_config["mcpServers"] = {}
-            current_config["mcpServers"][service_name] = normalized_config
-            self._store.config.save_config(current_config)
+            # 4. 更新mcp.json文件（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self._store._unified_config.add_service_config(service_name, normalized_config)
+            if not success:
+                raise Exception(f"Failed to update service config for {service_name}")
 
             # 5. 单源模式：不再同步到分片文件
             logger.info("Single-source mode: skip shard mapping files sync")
@@ -1186,7 +1285,7 @@ class ServiceManagementMixin:
 
     def get_service_status(self, name: str) -> dict:
         """获取单个服务的状态信息（同步版本）"""
-        return self._sync_helper.run_async(self.get_service_status_async(name))
+        return self._sync_helper.run_async(self.get_service_status_async(name), force_background=True)
 
     async def get_service_status_async(self, name: str) -> dict:
         """获取单个服务的状态信息"""
@@ -1206,7 +1305,8 @@ class ServiceManagementMixin:
 
     def restart_service(self, name: str) -> bool:
         """重启指定服务（同步版本）"""
-        return self._sync_helper.run_async(self.restart_service_async(name))
+        # 使用持久后台事件循环，避免 asyncio.run 的临时事件循环导致事件处理器被取消
+        return self._sync_helper.run_async(self.restart_service_async(name), force_background=True)
 
     async def restart_service_async(self, name: str) -> bool:
         """重启指定服务（透明代理）"""
@@ -1222,7 +1322,58 @@ class ServiceManagementMixin:
             logger.error(f"Failed to restart service {name}: {e}")
             return False
 
-    # === 🔧 新增：Agent 透明代理辅助方法 ===
+    # === Lifecycle-only disconnection (no config/registry deletion) ===
+    def disconnect_service(self, name: str, reason: str = "user_requested") -> bool:
+        """
+        断开服务（同步版本）- 仅生命周期断链：
+        - 不修改 mcp.json
+        - 不从注册表删除服务
+        - 将状态置为 disconnected，并清空工具展示
+        """
+        return self._sync_helper.run_async(
+            self.disconnect_service_async(name, reason=reason),
+            timeout=60.0,
+            force_background=True
+        )
+
+    async def disconnect_service_async(self, name: str, reason: str = "user_requested") -> bool:
+        """
+        断开服务（异步版本）- 仅生命周期断链：不改配置/不删注册表。
+
+        Store 上下文：name 视为全局名；
+        Agent 上下文：自动将本地名映射为全局名后断开。
+        """
+        try:
+            global_agent_id = self._store.client_manager.global_agent_store_id
+            if self._context_type == ContextType.STORE:
+                global_name = name
+            else:
+                global_name = await self._map_agent_service_to_global(name)
+
+            # 调用生命周期管理器执行优雅断开
+            lm = self._store.orchestrator.lifecycle_manager
+            await lm.graceful_disconnect(global_agent_id, global_name, reason)
+
+            # 清空工具展示缓存（仅清工具，不删除服务实体）
+            try:
+                self._store.registry.clear_service_tools_only(global_agent_id, global_name)
+            except Exception:
+                pass
+            # 触发快照更新（强一致）
+            try:
+                self._store.registry.tools_changed(global_agent_id, aggressive=True)
+            except Exception:
+                try:
+                    self._store.registry.mark_tools_snapshot_dirty()
+                except Exception:
+                    pass
+
+            return True
+        except Exception as e:
+            logger.error(f"[DISCONNECT_SERVICE] Failed to disconnect '{name}': {e}")
+            return False
+
+    # ===  新增：Agent 透明代理辅助方法 ===
 
     async def _map_agent_service_to_global(self, local_name: str) -> str:
         """
@@ -1239,15 +1390,15 @@ class ServiceManagementMixin:
                 # 尝试从映射关系中获取全局名称
                 global_name = self._store.registry.get_global_name_from_agent_service(self._agent_id, local_name)
                 if global_name:
-                    logger.debug(f"🔧 [SERVICE_PROXY] 服务名映射: {local_name} → {global_name}")
+                    logger.debug(f" [SERVICE_PROXY] 服务名映射: {local_name} → {global_name}")
                     return global_name
 
             # 如果映射失败，可能是 Store 原生服务，直接返回
-            logger.debug(f"🔧 [SERVICE_PROXY] 无映射，使用原名: {local_name}")
+            logger.debug(f" [SERVICE_PROXY] 无映射，使用原名: {local_name}")
             return local_name
 
         except Exception as e:
-            logger.error(f"❌ [SERVICE_PROXY] 服务名映射失败: {e}")
+            logger.error(f" [SERVICE_PROXY] 服务名映射失败: {e}")
             return local_name
 
     async def _delete_store_service_with_sync(self, service_name: str):
@@ -1259,16 +1410,13 @@ class ServiceManagementMixin:
                 service_name
             )
 
-            # 2. 从 mcp.json 中删除
-            current_config = self._store.config.load_config()
-            if "mcpServers" in current_config and service_name in current_config["mcpServers"]:
-                del current_config["mcpServers"][service_name]
-                success = self._store.config.save_config(current_config)
-
-                if success:
-                    logger.info(f" [SERVICE_DELETE] Store 服务删除成功: {service_name}")
-                else:
-                    logger.error(f"❌ [SERVICE_DELETE] Store 服务删除失败: {service_name}")
+            # 2. 从 mcp.json 中删除（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self._store._unified_config.remove_service_config(service_name)
+            
+            if success:
+                logger.info(f" [SERVICE_DELETE] Store 服务删除成功: {service_name}，缓存已同步")
+            else:
+                logger.error(f" [SERVICE_DELETE] Store 服务删除失败: {service_name}")
 
             # 3. 触发双向同步（如果是 Agent 服务）
             if hasattr(self._store, 'bidirectional_sync_manager'):
@@ -1278,7 +1426,7 @@ class ServiceManagementMixin:
                 )
 
         except Exception as e:
-            logger.error(f"❌ [SERVICE_DELETE] Store 服务删除失败 {service_name}: {e}")
+            logger.error(f" [SERVICE_DELETE] Store 服务删除失败 {service_name}: {e}")
             raise
 
     async def _delete_agent_service_with_sync(self, local_name: str):
@@ -1287,7 +1435,7 @@ class ServiceManagementMixin:
             # 1. 获取全局名称
             global_name = self._store.registry.get_global_name_from_agent_service(self._agent_id, local_name)
             if not global_name:
-                logger.warning(f"🔧 [SERVICE_DELETE] 未找到映射关系: {self._agent_id}:{local_name}")
+                logger.warning(f" [SERVICE_DELETE] 未找到映射关系: {self._agent_id}:{local_name}")
                 return
 
             # 2. 从 Agent 缓存中删除
@@ -1302,22 +1450,19 @@ class ServiceManagementMixin:
             # 4. 移除映射关系
             self._store.registry.remove_agent_service_mapping(self._agent_id, local_name)
 
-            # 5. 从 mcp.json 中删除
-            current_config = self._store.config.load_config()
-            if "mcpServers" in current_config and global_name in current_config["mcpServers"]:
-                del current_config["mcpServers"][global_name]
-                success = self._store.config.save_config(current_config)
-
-                if success:
-                    logger.info(f" [SERVICE_DELETE] Agent 服务删除成功: {local_name} → {global_name}")
-                else:
-                    logger.error(f"❌ [SERVICE_DELETE] Agent 服务删除失败: {local_name} → {global_name}")
+            # 5. 从 mcp.json 中删除（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self._store._unified_config.remove_service_config(global_name)
+            
+            if success:
+                logger.info(f" [SERVICE_DELETE] Agent 服务删除成功: {local_name} → {global_name}，缓存已同步")
+            else:
+                logger.error(f" [SERVICE_DELETE] Agent 服务删除失败: {local_name} → {global_name}")
 
             # 6. 单源模式：不再同步到分片文件
             logger.info("Single-source mode: skip shard mapping files sync")
 
         except Exception as e:
-            logger.error(f"❌ [SERVICE_DELETE] Agent 服务删除失败 {self._agent_id}:{local_name}: {e}")
+            logger.error(f" [SERVICE_DELETE] Agent 服务删除失败 {self._agent_id}:{local_name}: {e}")
             raise
 
     def show_mcpconfig(self) -> Dict[str, Any]:
@@ -1328,9 +1473,9 @@ class ServiceManagementMixin:
             Dict[str, Any]: Store上下文返回MCP JSON格式，Agent上下文返回client配置字典
         """
         if self._context_type == ContextType.STORE:
-            # Store上下文：返回MCP JSON格式的配置
+            # Store上下文：返回MCP JSON格式的配置（从缓存读取，更高效）
             try:
-                config = self._store.config.load_config()
+                config = self._store._unified_config.get_mcp_config()
                 # 确保返回格式正确
                 if isinstance(config, dict) and 'mcpServers' in config:
                     return config
@@ -1376,7 +1521,8 @@ class ServiceManagementMixin:
         """
         return self._sync_helper.run_async(
             self.wait_service_async(client_id_or_service_name, status, timeout, raise_on_timeout),
-            timeout=timeout + 1.0  # 给异步版本额外1秒缓冲
+            timeout=timeout + 1.0,  # 给异步版本额外1秒缓冲
+            force_background=True
         )
 
     async def wait_service_async(self, client_id_or_service_name: str,
@@ -1407,12 +1553,23 @@ class ServiceManagementMixin:
             # 在纯视图模式下，Agent 的状态查询统一使用全局命名空间
             status_agent_key = self._store.client_manager.global_agent_store_id
 
+
+            # 诊断：解析后的作用域与标识
+            try:
+                logger.info(f"[WAIT_SERVICE] resolved agent_scope={agent_scope} client_id='{client_id}' service='{service_name}' status_agent_key={status_agent_key}")
+            except Exception:
+                pass
+
             # 解析等待模式
             change_mode = False
             if isinstance(status, str) and status.lower() == 'change':
                 change_mode = True
                 logger.info(f"[WAIT_SERVICE] start mode=change service='{service_name}' timeout={timeout}s")
-                initial_status = self._store.orchestrator.get_service_comprehensive_status(service_name, status_agent_key)
+                try:
+                    initial_status = (self._store.orchestrator.get_service_status(service_name, status_agent_key) or {}).get("status", "unknown")
+                except Exception as _e_init:
+                    logger.debug(f"[WAIT_SERVICE] initial_status_error service='{service_name}' error={_e_init}")
+                    initial_status = "unknown"
             else:
                 # 规范化目标状态
                 target_statuses = self._normalize_target_statuses(status)
@@ -1436,14 +1593,25 @@ class ServiceManagementMixin:
                         raise TimeoutError(msg)
                     return False
 
-                # 获取当前状态
+                # 获取当前状态（先读一次缓存，随后在必要时读一次新缓存以防止竞态）
                 try:
-                    current_status = self._store.orchestrator.get_service_comprehensive_status(service_name, status_agent_key)
+
+                    status_dict = self._store.orchestrator.get_service_status(service_name, status_agent_key) or {}
+                    current_status = status_dict.get("status", "unknown")
 
                     # 仅在状态变化或每2秒节流一次打印
                     now = time.time()
                     if current_status != prev_status or (now - last_log) > 2.0:
                         logger.debug(f"[WAIT_SERVICE] status service='{service_name}' value='{current_status}'")
+                        # 对比 orchestrator 与 registry 的状态及最近健康检查（节流打印）
+                        try:
+                            reg_state = self._store.registry.get_service_state(status_agent_key, service_name)
+                            meta = self._store.registry.get_service_metadata(status_agent_key, service_name)
+                            last_check_ts = meta.last_health_check.isoformat() if getattr(meta, 'last_health_check', None) else None
+                            logger.debug(f"[WAIT_SERVICE] compare orchestrator='{current_status}' registry='{getattr(reg_state,'value',reg_state)}' last_check={last_check_ts}")
+                        except Exception:
+                            pass
+
                         prev_status, last_log = current_status, now
 
                     if change_mode:
@@ -1502,20 +1670,37 @@ class ServiceManagementMixin:
 
         return target_statuses
 
-    def _apply_auth_to_update_config(self, config: Dict[str, Any], 
-                                    auth: Optional[str], 
+    def _apply_auth_to_update_config(self, config: Dict[str, Any],
+                                    auth: Optional[str],
+                                    token: Optional[str],
+                                    api_key: Optional[str],
                                     headers: Optional[Dict[str, str]]) -> Dict[str, Any]:
-        """将认证配置应用到更新配置中"""
+        """将认证配置应用到更新配置中（标准化为 headers + 合并语义）"""
         final_config = config.copy() if config else {}
-        
-        if auth is not None:
-            final_config["auth"] = auth
-        
-        if headers is not None:
-            if "headers" not in final_config:
-                final_config["headers"] = {}
-            final_config["headers"].update(headers)
-        
+
+        # 构造标准化后的 headers
+        normalized_headers: Dict[str, str] = {}
+        eff_token = token if token else auth
+        if eff_token:
+            normalized_headers["Authorization"] = f"Bearer {eff_token}"
+        if api_key:
+            normalized_headers["X-API-Key"] = api_key
+        if headers:
+            normalized_headers.update(headers)
+
+        if normalized_headers:
+            existing = dict(final_config.get("headers", {}) or {})
+            existing.update(normalized_headers)
+            final_config["headers"] = existing
+
+        # 清理入口字段，避免持久化污染
+        for k in ("token", "api_key", "auth"):
+            if k in final_config:
+                try:
+                    del final_config[k]
+                except Exception:
+                    final_config.pop(k, None)
+
         return final_config
 
 
