@@ -4,12 +4,8 @@ User-friendly Session class that wraps AgentSession with rich functionality
 """
 
 import logging
-import asyncio
 from datetime import datetime
-from typing import Dict, List, Optional, Any, Union, TYPE_CHECKING
-
-from mcpstore.core.models.tool import ToolInfo
-from .types import ContextType
+from typing import Dict, List, Optional, Any, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from mcpstore.core.agents.session_manager import AgentSession
@@ -128,7 +124,8 @@ class Session:
         # Eagerly create and cache persistent client to avoid first-call delay
         try:
             orchestrator = self._context._store.orchestrator
-            client = await orchestrator._create_persistent_client(self._agent_session, service_name)
+            # Use public API exclusively
+            client = await orchestrator.ensure_persistent_client(self._agent_session, service_name)
             if client:
                 logger.info(f"[SESSION:{self._session_id}] Eager persistent client created for service '{service_name}'")
         except Exception as e:
@@ -143,7 +140,7 @@ class Session:
     
     # === Tool Execution ===
     
-    def use_tool(self, tool_name: str, arguments: Dict[str, Any] = None, **kwargs) -> Any:
+    def use_tool(self, tool_name: str, arguments: Dict[str, Any] = None, return_extracted: bool = False, **kwargs) -> Any:
         """
         Use tool within this session
 
@@ -181,7 +178,7 @@ class Session:
         logger.debug(f"[TIMING] Before run_async: +{(t_before_run_async - t_start)*1000:.1f}ms")
 
         result = self._context._sync_helper.run_async(
-            self.use_tool_async(tool_name, arguments, **kwargs),
+            self.use_tool_async(tool_name, arguments, return_extracted=return_extracted, **kwargs),
             timeout=wrapper_timeout,
             force_background=True
         )
@@ -191,7 +188,7 @@ class Session:
 
         return result
     
-    async def use_tool_async(self, tool_name: str, arguments: Dict[str, Any] = None, **kwargs) -> Any:
+    async def use_tool_async(self, tool_name: str, arguments: Dict[str, Any] = None, return_extracted: bool = False, **kwargs) -> Any:
         """
         Use tool within this session (async version)
         
@@ -206,8 +203,9 @@ class Session:
         # Tool name resolution and service binding will be handled downstream by call_tool_async
         # and orchestrator's session-aware execution path.
         result = await self._context.call_tool_async(
-            tool_name=tool_name, 
-            args=arguments, 
+            tool_name=tool_name,
+            args=arguments,
+            return_extracted=return_extracted,
             session_id=self._session_id,
             **kwargs
         )
@@ -526,9 +524,9 @@ class SessionContext:
         
         Now that SessionManagementMixin is integrated, we can use it to create sessions.
         """
-        # Use the context's session management to create a session
-        return self._context.create_session(self._session_id)
-    
+        # Use the context's session management to get or create a session (idempotent)
+        return self._context.get_session(self._session_id)
+
     async def _close_session_async(self):
         """
         Internal method to close session asynchronously
