@@ -25,29 +25,20 @@ class ToolOperationsMixin:
         - 本地服务：最多等待5秒
         - 状态确定后立即返回
         """
-        # 🔧 智能等待：先等待INITIALIZING服务就绪
-        # 快速路径：如果没有INITIALIZING服务，跳过等待
-        if hasattr(self, '_has_initializing_services'):
-            from .types import ContextType
-            agent_id = self._agent_id if self._context_type == ContextType.AGENT else self._store.client_manager.global_agent_store_id
-            has_initializing = self._has_initializing_services(agent_id)
-
-            if has_initializing:
-                logger.info(f"[LIST_TOOLS] initializing_detected smart_wait start")
-                if hasattr(self, '_wait_for_initializing_services'):
-                    self._sync_helper.run_async(self._wait_for_initializing_services(), force_background=True)
-                else:
-                    logger.warning("[LIST_TOOLS] _wait_for_initializing_services missing")
-            else:
-                logger.debug("[LIST_TOOLS] no_initializing skip_smart_wait")
-        else:
-            logger.debug("[LIST_TOOLS] quick_check_unavailable skip_smart_wait")
-
-        # 然后获取工具列表
-        logger.info(f"[LIST_TOOLS] start")
-        # Avoid forcing background loop to reduce nested loop overhead; set reasonable timeout
-        result = self._sync_helper.run_async(self.list_tools_async(), timeout=60.0)
-        logger.info(f"[LIST_TOOLS] count={len(result)}")
+        # 统一等待策略：从 orchestrator 获取一致性快照，避免在 context 层做临时等待
+        logger.info(f"[LIST_TOOLS] start (snapshot)")
+        try:
+            agent_id = self._agent_id if self._context_type == ContextType.AGENT else None
+            snapshot = self._store.orchestrator._sync_helper.run_async(
+                self._store.orchestrator.tools_snapshot(agent_id),
+                force_background=True
+            )
+            # 映射为 ToolInfo
+            result = [ToolInfo(**t) for t in snapshot if isinstance(t, dict)]
+        except Exception as e:
+            logger.error(f"[LIST_TOOLS] snapshot error: {e}")
+            result = []
+        logger.info(f"[LIST_TOOLS] count={len(result) if result else 0}")
         if result:
             logger.info(f"[LIST_TOOLS] names={[t.name for t in result]}")
         else:
@@ -60,11 +51,10 @@ class ToolOperationsMixin:
         - store context: aggregate tools from all client_ids under global_agent_store
         - agent context: aggregate tools from all client_ids under agent_id (show local names)
         """
-        if self._context_type == ContextType.STORE:
-            return await self._store.list_tools()
-        else:
-            # Agent模式：透明代理 - 获取 Agent 的工具并转换为本地名称
-            return await self._get_agent_tools_view()
+        # 统一改为读取 orchestrator 快照（无回退、无旧路径）
+        agent_id = self._agent_id if self._context_type == ContextType.AGENT else None
+        snapshot = await self._store.orchestrator.tools_snapshot(agent_id)
+        return [ToolInfo(**t) for t in snapshot if isinstance(t, dict)]
 
     def get_tools_with_stats(self) -> Dict[str, Any]:
         """
@@ -73,7 +63,7 @@ class ToolOperationsMixin:
         Returns:
             Dict: 包含工具列表和统计信息
         """
-        return self._sync_helper.run_async(self.get_tools_with_stats_async())
+        return self._sync_helper.run_async(self.get_tools_with_stats_async(), force_background=True)
 
     async def get_tools_with_stats_async(self) -> Dict[str, Any]:
         """
@@ -85,7 +75,7 @@ class ToolOperationsMixin:
         try:
             tools = await self.list_tools_async()
             
-            # 🔧 修复：返回完整的工具信息，包括Vue前端需要的所有字段
+            #  修复：返回完整的工具信息，包括Vue前端需要的所有字段
             tools_data = [
                 {
                     "name": tool.name,
@@ -106,7 +96,7 @@ class ToolOperationsMixin:
                     tools_by_service[service_name] = 0
                 tools_by_service[service_name] += 1
 
-            # 🔧 修复：返回API期望的格式
+            #  修复：返回API期望的格式
             return {
                 "tools": tools_data,
                 "metadata": {
@@ -118,7 +108,7 @@ class ToolOperationsMixin:
             
         except Exception as e:
             logger.error(f"Failed to get tools with stats: {e}")
-            # 🔧 修复：错误情况下也返回API期望的格式
+            #  修复：错误情况下也返回API期望的格式
             return {
                 "tools": [],
                 "metadata": {
@@ -246,14 +236,14 @@ class ToolOperationsMixin:
                 "total_added": 0
             }
 
-    def call_tool(self, tool_name: str, args: Union[Dict[str, Any], str] = None, **kwargs) -> Any:
+    def call_tool(self, tool_name: str, args: Union[Dict[str, Any], str] = None, return_extracted: bool = False, **kwargs) -> Any:
         """
         调用工具（同步版本），支持 store/agent 上下文
 
-        用户友好的工具调用接口，支持多种工具名称格式：
+        用户友好的工具调用接口，支持以下工具名称格式：
         - 直接工具名: "get_weather"
-        - 服务前缀: "weather__get_weather"
-        - 旧格式: "weather_get_weather"
+        - 服务前缀（单下划线）: "weather_get_weather"
+        注意：不再支持双下划线格式 "service__tool"；如使用将抛出错误并提示迁移方案
 
         Args:
             tool_name: 工具名称（支持多种格式）
@@ -267,18 +257,18 @@ class ToolOperationsMixin:
         """
         # Use background event loop to preserve persistent FastMCP clients across sync calls
         # Especially critical in auto-session mode to avoid per-call asyncio.run() closing loops
-        return self._sync_helper.run_async(self.call_tool_async(tool_name, args, **kwargs), force_background=True)
+        return self._sync_helper.run_async(self.call_tool_async(tool_name, args, return_extracted=return_extracted, **kwargs), force_background=True)
 
-    def use_tool(self, tool_name: str, args: Union[Dict[str, Any], str] = None, **kwargs) -> Any:
+    def use_tool(self, tool_name: str, args: Union[Dict[str, Any], str] = None, return_extracted: bool = False, **kwargs) -> Any:
         """
         使用工具（同步版本）- 向后兼容别名
 
         注意：此方法是 call_tool 的别名，保持向后兼容性。
         推荐使用 call_tool 方法，与 FastMCP 命名保持一致。
         """
-        return self.call_tool(tool_name, args, **kwargs)
+        return self.call_tool(tool_name, args, return_extracted=return_extracted, **kwargs)
 
-    async def call_tool_async(self, tool_name: str, args: Dict[str, Any] = None, **kwargs) -> Any:
+    async def call_tool_async(self, tool_name: str, args: Dict[str, Any] = None, return_extracted: bool = False, **kwargs) -> Any:
         """
         调用工具（异步版本），支持 store/agent 上下文
 
@@ -300,12 +290,12 @@ class ToolOperationsMixin:
                 logger.debug(f"[IMPLICIT_SESSION] Routing tool '{tool_name}' to active session")
             # Avoid duplicate session_id when delegating to Session API
             kwargs.pop('session_id', None)
-            return await self._active_session.use_tool_async(tool_name, args, **kwargs)
+            return await self._active_session.use_tool_async(tool_name, args, return_extracted=return_extracted, **kwargs)
 
         # 🎯 自动会话路由：仅当启用了自动会话且未显式指定 session_id 时才路由
         if getattr(self, '_auto_session_enabled', False) and 'session_id' not in kwargs:
             logger.debug(f"[AUTO_SESSION] Routing tool '{tool_name}' to auto session (no explicit session_id)")
-            return await self._use_tool_with_session_async(tool_name, args, **kwargs)
+            return await self._use_tool_with_session_async(tool_name, args, return_extracted=return_extracted, **kwargs)
         elif getattr(self, '_auto_session_enabled', False) and 'session_id' in kwargs:
             logger.debug("[AUTO_SESSION] Enabled but explicit session_id provided; skip auto routing")
 
@@ -314,7 +304,7 @@ class ToolOperationsMixin:
         if active_session is not None and getattr(active_session, 'is_active', False) and 'session_id' not in kwargs:
             logger.debug(f"[ACTIVE_SESSION] Routing tool '{tool_name}' to active session '{active_session.session_id}'")
             kwargs.pop('session_id', None)
-            return await active_session.use_tool_async(tool_name, args, **kwargs)
+            return await active_session.use_tool_async(tool_name, args, return_extracted=return_extracted, **kwargs)
 
         # 获取可用工具列表用于智能解析
         available_tools = []
@@ -328,7 +318,7 @@ class ToolOperationsMixin:
             for tool in tools:
                 # Agent模式：需要转换服务名称为本地名称
                 if self._context_type == ContextType.AGENT and self._agent_id:
-                    # 🔧 透明代理：将全局服务名转换为本地服务名
+                    #  透明代理：将全局服务名转换为本地服务名
                     local_service_name = self._get_local_service_name_from_global(tool.service_name)
                     if local_service_name:
                         # 构建本地工具名称
@@ -401,7 +391,14 @@ class ToolOperationsMixin:
             logger.info(f"[SMART_RESOLVE] input='{tool_name}' fastmcp='{fastmcp_tool_name}' service='{resolution.service_name}' method='{resolution.resolution_method}'")
 
         except ValueError as e:
-            raise ValueError(f"智能工具解析失败: {e}")
+            # LLM-readable error: tool name resolution failed, return structured error for model understanding
+            return {
+                "content": [{
+                    "type": "text",
+                    "text": f"[LLM Hint] Tool name resolution failed: {str(e)}. Please check the tool name or add service prefix, e.g. service_tool."
+                }],
+                "is_error": True
+            }
 
         # 构造标准化的工具执行请求
         from mcpstore.core.models.tool import ToolExecutionRequest
@@ -423,11 +420,34 @@ class ToolOperationsMixin:
                 tool_name=fastmcp_tool_name,  # 🚀 使用FastMCP标准格式
                 service_name=global_service_name,  # 使用全局服务名称
                 args=args,
-                agent_id=self._store.client_manager.global_agent_store_id,  # 🔧 使用全局 Agent ID
+                agent_id=self._store.client_manager.global_agent_store_id,  #  使用全局 Agent ID
                 **kwargs
             )
 
-        return await self._store.process_tool_request(request)
+        response = await self._store.process_tool_request(request)
+
+        # Convert execution errors to LLM-readable format to avoid code interruption
+        if hasattr(response, 'success') and not response.success:
+            msg = getattr(response, 'error', 'Tool execution failed')
+            return {
+                "content": [{
+                    "type": "text",
+                    "text": f"[LLM Hint] Tool invocation failed: {msg}"
+                }],
+                "is_error": True
+            }
+
+        if return_extracted:
+            try:
+                from mcpstore.core.registry.tool_resolver import FastMCPToolExecutor
+                executor = FastMCPToolExecutor()
+                return executor.extract_result_data(response.result)
+            except Exception:
+                # 兜底：无法提取则直接返回原结果
+                return getattr(response, 'result', None)
+        else:
+            # 默认返回 FastMCP 的 CallToolResult（或等价对象）
+            return getattr(response, 'result', None)
 
     async def use_tool_async(self, tool_name: str, args: Dict[str, Any] = None, **kwargs) -> Any:
         """
@@ -438,7 +458,7 @@ class ToolOperationsMixin:
         """
         return await self.call_tool_async(tool_name, args, **kwargs)
 
-    # === 🔧 新增：Agent 工具调用透明代理方法 ===
+    # ===  新增：Agent 工具调用透明代理方法 ===
 
     async def _map_agent_tool_to_global_service(self, local_service_name: str, tool_name: str) -> str:
         """
@@ -556,16 +576,16 @@ class ToolOperationsMixin:
             str: 本地工具名
         """
         try:
-            # 如果工具名以全局服务名开头，替换为本地服务名
+            # If tool name starts with global service name, replace with local service name
             if global_tool_name.startswith(f"{global_service_name}_"):
                 tool_suffix = global_tool_name[len(global_service_name) + 1:]
                 return f"{local_service_name}_{tool_suffix}"
             else:
-                # 如果不符合预期格式，直接返回原工具名
+                # If format doesn't match, return original tool name
                 return global_tool_name
 
         except Exception as e:
-            logger.error(f"❌ [TOOL_NAME_CONVERT] 工具名转换失败: {e}")
+            logger.error(f"[TOOL_NAME_CONVERT] Tool name conversion failed: {e}")
             return global_tool_name
 
     def _get_local_service_name_from_global(self, global_service_name: str) -> Optional[str]:
@@ -582,7 +602,7 @@ class ToolOperationsMixin:
             if not self._agent_id:
                 return None
 
-            # 检查映射关系
+            # Check mapping relationship
             agent_mappings = self._store.registry.agent_to_global_mappings.get(self._agent_id, {})
             for local_name, global_name in agent_mappings.items():
                 if global_name == global_service_name:
@@ -591,5 +611,5 @@ class ToolOperationsMixin:
             return None
 
         except Exception as e:
-            logger.error(f"❌ [SERVICE_NAME_CONVERT] 服务名转换失败: {e}")
+            logger.error(f"[SERVICE_NAME_CONVERT] Service name conversion failed: {e}")
             return None
