@@ -1,6 +1,6 @@
 from datetime import datetime
 from enum import Enum
-from typing import Optional, List, Dict, Any, Literal, Union
+from typing import Optional, List, Dict, Any, Union
 
 from pydantic import BaseModel, Field
 
@@ -32,15 +32,17 @@ class ServiceStateMetadata(BaseModel):
     last_failure_time: Optional[datetime] = None
     response_time: Optional[float] = None
     error_message: Optional[str] = None
+    # failure_reason 用于分类错误原因，例如 "auth_failed"、"network_error" 等
+    failure_reason: Optional[str] = None
     reconnect_attempts: int = 0
     next_retry_time: Optional[datetime] = None
     state_entered_time: Optional[datetime] = None
     disconnect_reason: Optional[str] = None
-    # 🔧 新增：服务配置信息
+    #  新增：服务配置信息
     service_config: Dict[str, Any] = Field(default_factory=dict)
     service_name: Optional[str] = None
     agent_id: Optional[str] = None
-    # 🔧 修复：添加缺失的字段
+    #  修复：添加缺失的字段
     last_health_check: Optional[datetime] = None
     last_response_time: Optional[float] = None
 
@@ -62,7 +64,7 @@ class ServiceInfo(BaseModel):
     state_metadata: Optional[ServiceStateMetadata] = None
     last_state_change: Optional[datetime] = None
     client_id: Optional[str] = None  # Add client_id field
-    config: Dict[str, Any] = Field(default_factory=dict)  # 🔧 [REFACTOR] 添加完整的config字段
+    config: Dict[str, Any] = Field(default_factory=dict)  #  [REFACTOR] 添加完整的config字段
 
 class ServiceInfoResponse(BaseModel):
     """Detailed information response model for a single service"""
