@@ -3,32 +3,25 @@ MCPOrchestrator Base Module
 Orchestrator core base module - contains infrastructure and lifecycle management
 """
 
-import os
-import sys
-import asyncio
 import logging
 import time
-from typing import Dict, List, Any, Optional, Tuple
-from datetime import datetime, timedelta
+from typing import Dict, Any, Optional
 
-from mcpstore.core.registry import ServiceRegistry
-from mcpstore.core.client_manager import ClientManager
-from mcpstore.core.configuration.config_processor import ConfigProcessor
-from mcpstore.core.integration.local_service_adapter import get_local_service_manager
 from fastmcp import Client
+
 from mcpstore.config.json_config import MCPConfig
 from mcpstore.core.agents.session_manager import SessionManager
-from mcpstore.core.lifecycle import get_health_manager, HealthStatus, HealthCheckResult, ServiceLifecycleManager, ServiceContentManager
-from mcpstore.core.models.service import ServiceConnectionState
-
+from mcpstore.core.store.client_manager import ClientManager
+from mcpstore.core.integration.local_service_adapter import get_local_service_manager
+from mcpstore.core.registry import ServiceRegistry
 # Import mixin classes
 from .monitoring_tasks import MonitoringTasksMixin
-from .service_connection import ServiceConnectionMixin
-from .tool_execution import ToolExecutionMixin
-from .service_management import ServiceManagementMixin
-from .resources_prompts import ResourcesPromptsMixin
 from .network_utils import NetworkUtilsMixin
+from .resources_prompts import ResourcesPromptsMixin
+from .service_connection import ServiceConnectionMixin
+from .service_management import ServiceManagementMixin
 from .standalone_config import StandaloneConfigMixin
+from .tool_execution import ToolExecutionMixin
 
 logger = logging.getLogger(__name__)
 
@@ -69,16 +62,19 @@ class MCPOrchestrator(
         # 智能重连功能已集成到ServiceLifecycleManager中
         self.react_agent = None
 
-        # 🔧 新增：独立配置管理器
+        #  新增：独立配置管理器
         self.standalone_config_manager = standalone_config_manager
 
-        # 🔧 新增：统一同步管理器
+        #  新增：统一同步管理器
         self.sync_manager = None
 
-        # 🔧 新增：store引用（用于统一注册架构）
-        self.store = None
+        #  新增：ServiceContainer引用（替代 store 引用，解除循环依赖）
+        self.container = None
 
-        # 🔧 新增：异步同步助手（用于Resources和Prompts的同步方法）
+        #  新增：Context工厂函数（用于服务注册，替代 store.for_store()）
+        self._context_factory = None
+
+        #  新增：异步同步助手（用于Resources和Prompts的同步方法）
         from mcpstore.core.utils.async_sync_helper import AsyncSyncHelper
         self._sync_helper = AsyncSyncHelper()
 
@@ -89,7 +85,7 @@ class MCPOrchestrator(
 
         # 监控任务已集成到ServiceLifecycleManager和ServiceContentManager中
 
-        # 🔧 修改：根据是否有独立配置管理器或传入的mcp_config决定如何初始化MCPConfig
+        #  修改：根据是否有独立配置管理器或传入的mcp_config决定如何初始化MCPConfig
         if standalone_config_manager:
             # 使用独立配置，不依赖文件系统
             self.mcp_config = self._create_standalone_mcp_config(standalone_config_manager)
@@ -103,7 +99,7 @@ class MCPOrchestrator(
         # 旧的资源管理配置已被ServiceLifecycleManager替代
         # 保留一些配置以避免错误，但实际不再使用
 
-        # 🔧 单一数据源架构：简化客户端管理器初始化
+        #  单一数据源架构：简化客户端管理器初始化
         self.client_manager = ClientManager(
             global_agent_store_id=None  # 使用默认的"global_agent_store"
         )
@@ -115,14 +111,14 @@ class MCPOrchestrator(
         # 本地服务管理器
         self.local_service_manager = get_local_service_manager()
 
-        # 健康管理器
-        self.health_manager = get_health_manager()
 
-        # 服务生命周期管理器
-        self.lifecycle_manager = ServiceLifecycleManager(self)
+        # 🆕 事件驱动架构：生命周期管理器将由 ServiceContainer 管理
+        # 保留属性以兼容旧代码，但实际使用 store.container.lifecycle_manager
+        self.lifecycle_manager = None  # 将在 store 初始化后设置
 
-        # 服务内容管理器（替代旧的工具更新监控器）
-        self.content_manager = ServiceContentManager(self)
+        # 🆕 事件驱动架构：内容管理器暂时保留（未来可能迁移到事件驱动）
+        # self.content_manager = ServiceContentManager(self)
+        self.content_manager = None  # 暂时禁用，避免依赖旧的 lifecycle_manager
 
         # 旧的工具更新监控器（保留兼容性，但将被废弃）
         self.tools_update_monitor = None
@@ -177,26 +173,20 @@ class MCPOrchestrator(
 
     async def setup(self):
         """初始化编排器资源"""
-        # 检查是否已经初始化
-        if (hasattr(self, 'lifecycle_manager') and
-            self.lifecycle_manager and
-            self.lifecycle_manager.is_running):
-            logger.info("MCP Orchestrator already set up, skipping...")
-            return
-
         logger.info("Setting up MCP Orchestrator...")
 
-        # 初始化健康管理器配置
-        self._update_health_manager_config()
+        # 健康管理器配置已移除（事件驱动架构直接使用容器的 HealthMonitor）
 
         # 初始化工具更新监控器
         self._setup_tools_update_monitor()
 
-        # 启动生命周期管理器
-        await self.lifecycle_manager.start()
-
-        # 启动内容管理器
-        await self.content_manager.start()
+        # 🆕 事件驱动架构：启动 ServiceContainer（如果已设置）
+        if self.container:
+            logger.info("Starting ServiceContainer components...")
+            await self.container.start()
+            logger.info("ServiceContainer components started")
+        else:
+            logger.warning("ServiceContainer not available, skipping container startup")
 
         # 启动监控任务（仅启动保留的工具更新监控器）
         try:
@@ -204,7 +194,7 @@ class MCPOrchestrator(
         except Exception as e:
             logger.warning(f"Failed to start monitoring tasks: {e}")
 
-        # 🔧 新增：启动统一同步管理器
+        #  新增：启动统一同步管理器
         try:
             logger.info("About to call _setup_sync_manager()...")
             await self._setup_sync_manager()
@@ -215,7 +205,7 @@ class MCPOrchestrator(
             logger.error(f"_setup_sync_manager() traceback: {traceback.format_exc()}")
 
         # 只做必要的资源初始化
-        logger.info("MCP Orchestrator setup completed with lifecycle, content management and unified sync")
+        logger.info("MCP Orchestrator setup completed with event-driven architecture")
 
     async def _setup_sync_manager(self):
         """设置统一同步管理器"""
@@ -257,13 +247,11 @@ class MCPOrchestrator(
                 await self.sync_manager.stop()
                 self.sync_manager = None
 
-            # 停止生命周期管理器
-            if hasattr(self, 'lifecycle_manager') and self.lifecycle_manager:
-                await self.lifecycle_manager.stop()
-
-            # 停止内容管理器
-            if hasattr(self, 'content_manager') and self.content_manager:
-                await self.content_manager.stop()
+            # 🆕 事件驱动架构：停止 ServiceContainer
+            if self.container:
+                logger.info("Stopping ServiceContainer components...")
+                await self.container.stop()
+                logger.info("ServiceContainer components stopped")
 
             logger.info("MCP Orchestrator cleanup completed")
 
@@ -274,91 +262,22 @@ class MCPOrchestrator(
         """关闭编排器并清理资源"""
         logger.info("Shutting down MCP Orchestrator...")
 
-        # 🔧 修复：按正确顺序停止管理器，并添加错误处理
+        # 🆕 事件驱动架构：停止 ServiceContainer
         try:
-            # 先停止生命周期管理器（停止状态转换）
-            logger.debug("Stopping lifecycle manager...")
-            await self.lifecycle_manager.stop()
-            logger.debug("Lifecycle manager stopped")
+            if self.container:
+                logger.debug("Stopping ServiceContainer...")
+                await self.container.stop()
+                logger.debug("ServiceContainer stopped")
         except Exception as e:
-            logger.error(f"Error stopping lifecycle manager: {e}")
-
-        try:
-            # 再停止内容管理器（停止内容更新）
-            logger.debug("Stopping content manager...")
-            await self.content_manager.stop()
-            logger.debug("Content manager stopped")
-        except Exception as e:
-            logger.error(f"Error stopping content manager: {e}")
-
-        # 旧的后台任务已被废弃，无需停止
-        logger.info("Legacy monitoring tasks were already disabled")
+            logger.error(f"Error stopping ServiceContainer: {e}")
 
         logger.info("MCP Orchestrator shutdown completed")
 
-    def _update_health_manager_config(self):
-        """更新健康管理器配置"""
-        try:
-            # 从配置中提取健康相关设置
-            timing_config = self.config.get("timing", {})
-
-            # 构建健康管理器配置
-            health_config = {
-                "local_service_ping_timeout": timing_config.get("local_service_ping_timeout", 3),
-                "remote_service_ping_timeout": timing_config.get("remote_service_ping_timeout", 5),
-                "startup_wait_time": timing_config.get("startup_wait_time", 2),
-                "healthy_response_threshold": timing_config.get("healthy_response_threshold", 1.0),
-                "warning_response_threshold": timing_config.get("warning_response_threshold", 3.0),
-                "slow_response_threshold": timing_config.get("slow_response_threshold", 10.0),
-                "enable_adaptive_timeout": timing_config.get("enable_adaptive_timeout", False),
-                "adaptive_timeout_multiplier": timing_config.get("adaptive_timeout_multiplier", 2.0),
-                "response_time_history_size": timing_config.get("response_time_history_size", 10)
-            }
-
-            # 更新健康管理器配置
-            self.health_manager.update_config(health_config)
-            logger.info(f"Health manager configuration updated: {health_config}")
-
-        except Exception as e:
-            logger.warning(f"Failed to update health manager config: {e}")
-
-    def update_monitoring_config(self, monitoring_config: Dict[str, Any]):
-        """更新监控配置（包括健康检查配置）"""
-        try:
-            # 更新时间配置
-            if "timing" not in self.config:
-                self.config["timing"] = {}
-
-            # 映射监控配置到时间配置
-            timing_mapping = {
-                "local_service_ping_timeout": "local_service_ping_timeout",
-                "remote_service_ping_timeout": "remote_service_ping_timeout",
-                "startup_wait_time": "startup_wait_time",
-                "healthy_response_threshold": "healthy_response_threshold",
-                "warning_response_threshold": "warning_response_threshold",
-                "slow_response_threshold": "slow_response_threshold",
-                "enable_adaptive_timeout": "enable_adaptive_timeout",
-                "adaptive_timeout_multiplier": "adaptive_timeout_multiplier",
-                "response_time_history_size": "response_time_history_size"
-            }
-
-            for monitor_key, timing_key in timing_mapping.items():
-                if monitor_key in monitoring_config and monitoring_config[monitor_key] is not None:
-                    self.config["timing"][timing_key] = monitoring_config[monitor_key]
-
-            # 更新健康管理器配置
-            self._update_health_manager_config()
-
-            logger.info("Monitoring configuration updated successfully")
-
-        except Exception as e:
-            logger.error(f"Failed to update monitoring config: {e}")
-            raise
 
     def _setup_tools_update_monitor(self):
         """设置工具更新监控器"""
         try:
-            from mcpstore.core.monitoring import ToolsUpdateMonitor
+            from mcpstore.extensions.monitoring import ToolsUpdateMonitor
             self.tools_update_monitor = ToolsUpdateMonitor(self)
             logger.info("Tools update monitor initialized")
         except Exception as e:
