@@ -3,26 +3,23 @@ MCPOrchestrator Service Connection Module
 Service connection module - contains service connection and state management
 """
 
-import asyncio
 import logging
 from typing import Dict, List, Any, Optional, Tuple
 
-from mcpstore.core.configuration.config_processor import ConfigProcessor
 from fastmcp import Client
-from mcpstore.core.lifecycle import HealthStatus, HealthCheckResult
-from mcpstore.core.lifecycle.health_bridge import HealthStatusBridge
-from .health_monitoring import HealthMonitoringMixin
+
+from mcpstore.core.models.service import ServiceConnectionState
 
 logger = logging.getLogger(__name__)
 
-class ServiceConnectionMixin(HealthMonitoringMixin):
+class ServiceConnectionMixin:
     """Service connection mixin class"""
 
     async def connect_service(self, name: str, service_config: Dict[str, Any] = None, url: str = None, agent_id: str = None) -> Tuple[bool, str]:
         """
         Connect to specified service (supports local and remote services) and update cache
 
-        🔧 缓存优先架构：优先从缓存获取配置，支持完整的服务配置
+         ??????????????????????????
 
         Args:
             name: Service name
@@ -34,26 +31,26 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             Tuple[bool, str]: (success status, message)
         """
         try:
-            # 确定Agent ID
+            # ??Agent ID
             agent_key = agent_id or self.client_manager.global_agent_store_id
 
-            # 🔧 缓存优先：从缓存获取服务配置
+            #  ??????????????
             if service_config is None:
                 service_config = self.registry.get_service_config_from_cache(agent_key, name)
                 if not service_config:
                     return False, f"Service configuration not found in cache for {name}. This indicates a system issue."
 
-            # 如果提供了URL，更新配置（向后兼容）
+            # ?????URL???????????
             if url:
-                service_config = service_config.copy()  # 不修改原始缓存
+                service_config = service_config.copy()  # ???????
                 service_config["url"] = url
 
-            # 判断是本地服务还是远程服务
+            # ?????????????
             if "command" in service_config:
-                # 本地服务：先启动进程，再连接
+                # ??????????????
                 return await self._connect_local_service(name, service_config, agent_key)
             else:
-                # 远程服务：直接连接
+                # ?????????
                 return await self._connect_remote_service(name, service_config, agent_key)
 
         except Exception as e:
@@ -61,18 +58,18 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             return False, str(e)
 
     async def _connect_local_service(self, name: str, service_config: Dict[str, Any], agent_id: str) -> Tuple[bool, str]:
-        """连接本地服务并更新缓存"""
+        """???????????"""
         try:
-            # 1. 启动本地服务进程
+            # 1. ????????
             success, message = await self.local_service_manager.start_local_service(name, service_config)
             if not success:
                 return False, f"Failed to start local service: {message}"
 
-            #创建客户端连接
-            # 本地服务通常使用 stdio 传输
+            #???????
+            # ???????? stdio ??
             local_config = service_config.copy()
 
-            # 🔧 修复：使用 ConfigProcessor 处理配置（与remote service保持一致）
+            #  ????? ConfigProcessor ??????remote service?????
             from mcpstore.core.configuration.config_processor import ConfigProcessor
             processed_config = ConfigProcessor.process_user_config_for_fastmcp({
                 "mcpServers": {name: local_config}
@@ -81,21 +78,21 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             if name not in processed_config.get("mcpServers", {}):
                 return False, "Local service configuration processing failed"
 
-            # 创建客户端
+            # ?????
             client = Client(processed_config)
 
-            # 尝试连接和获取工具列表
+            # ???????????
             try:
                 async with client:
                     tools = await client.list_tools()
 
-                    # 🔧 修复：更新Registry缓存
+                    #  ?????Registry????????client?Registry?????????
                     await self._update_service_cache(agent_id, name, client, tools, service_config)
 
-                    # 更新客户端缓存（保持向后兼容）
-                    self.clients[name] = client
+                    # ?????? client?async with ????????
+                    # self.clients[name] = client
 
-                    # 🔧 修复：通知生命周期管理器连接成功
+                    #  ????????????????
                     await self.lifecycle_manager.handle_health_check_result(
                         agent_id=agent_id,
                         service_name=name,
@@ -110,15 +107,15 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 error_msg = str(e)
                 logger.error(f"Failed to connect to local service {name}: {error_msg}")
 
-                # 🔧 修复：清理资源，避免僵尸进程
+                #  ??????????????
                 try:
-                    # 停止本地服务进程
+                    # ????????
                     await self.local_service_manager.stop_local_service(name)
                     logger.debug(f"Cleaned up local service process for {name}")
                 except Exception as cleanup_error:
                     logger.error(f"Failed to cleanup local service {name}: {cleanup_error}")
 
-                # 清理客户端缓存
+                # ???????
                 if name in self.clients:
                     try:
                         client = self.clients[name]
@@ -129,7 +126,7 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                     except Exception as cleanup_error:
                         logger.error(f"Failed to cleanup client cache for {name}: {cleanup_error}")
 
-                # 通知生命周期管理器连接失败
+                # ?????????????
                 await self.lifecycle_manager.handle_health_check_result(
                     agent_id=agent_id,
                     service_name=name,
@@ -144,15 +141,15 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             error_msg = str(e)
             logger.error(f"Error connecting local service {name}: {error_msg}")
 
-            # 🔧 修复：清理资源，避免僵尸进程
+            #  ??????????????
             try:
-                # 停止本地服务进程
+                # ????????
                 await self.local_service_manager.stop_local_service(name)
                 logger.debug(f"Cleaned up local service process for {name} after outer exception")
             except Exception as cleanup_error:
                 logger.error(f"Failed to cleanup local service {name} after outer exception: {cleanup_error}")
 
-            # 清理客户端缓存
+            # ???????
             if name in self.clients:
                 try:
                     client = self.clients[name]
@@ -163,7 +160,7 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 except Exception as cleanup_error:
                     logger.error(f"Failed to cleanup client cache for {name} after outer exception: {cleanup_error}")
 
-            # 通知生命周期管理器连接失败
+            # ?????????????
             await self.lifecycle_manager.handle_health_check_result(
                 agent_id=agent_id,
                 service_name=name,
@@ -175,40 +172,40 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             return False, error_msg
 
     async def _connect_remote_service(self, name: str, service_config: Dict[str, Any], agent_id: str) -> Tuple[bool, str]:
-        """连接远程服务并更新缓存"""
+        """???????????"""
         try:
-            # 🔧 修复：使用ConfigProcessor处理配置，确保transport字段正确
+            #  ?????ConfigProcessor???????transport????
             from mcpstore.core.configuration.config_processor import ConfigProcessor
 
-            # 构造配置格式
+            # ??????
             user_config = {"mcpServers": {name: service_config}}
 
-            # 使用ConfigProcessor处理配置（与register_json_services保持一致）
+            # ??ConfigProcessor??????register_json_services?????
             processed_config = ConfigProcessor.process_user_config_for_fastmcp(user_config)
 
-            # 检查处理后的配置
+            # ????????
             if name not in processed_config.get("mcpServers", {}):
                 return False, f"Service configuration processing failed for {name}"
 
-            # 创建新的客户端（使用处理后的配置）
+            # ?????????????????
             client = Client(processed_config)
 
-            # 尝试连接
+            # ????
             try:
-                logger.info(f" [REMOTE_SERVICE] 准备进入 async with client 上下文: {name}")
+                logger.info(f" [REMOTE_SERVICE] ???? async with client ???: {name}")
                 async with client:
-                    logger.info(f" [REMOTE_SERVICE] 成功进入 async with client 上下文: {name}")
-                    logger.info(f" [REMOTE_SERVICE] 准备调用 client.list_tools(): {name}")
+                    logger.info(f" [REMOTE_SERVICE] ???? async with client ???: {name}")
+                    logger.info(f" [REMOTE_SERVICE] ???? client.list_tools(): {name}")
                     tools = await client.list_tools()
-                    logger.info(f" [REMOTE_SERVICE] 成功获取工具列表，数量: {len(tools)}")
+                    logger.info(f" [REMOTE_SERVICE] ???????????: {len(tools)}")
 
-                    # 🔧 修复：更新Registry缓存
+                    #  ?????Registry??
                     await self._update_service_cache(agent_id, name, client, tools, service_config)
 
-                    # 更新客户端缓存（保持向后兼容）
-                    self.clients[name] = client
+                    # ????? client?async with ?????????
+                    # self.clients[name] = client
 
-                    # 🔧 修复：通知生命周期管理器连接成功
+                    #  ????????????????
                     await self.lifecycle_manager.handle_health_check_result(
                         agent_id=agent_id,
                         service_name=name,
@@ -223,8 +220,8 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 error_msg = str(e)
                 logger.warning(f"Failed to connect to remote service {name}: {error_msg}")
 
-                # 🔧 修复：清理资源，避免资源泄漏
-                # 清理客户端缓存
+                #  ??????????????
+                # ???????
                 if name in self.clients:
                     try:
                         cached_client = self.clients[name]
@@ -235,7 +232,7 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                     except Exception as cleanup_error:
                         logger.error(f"Failed to cleanup client cache for remote service {name}: {cleanup_error}")
 
-                # 确保当前客户端也被正确关闭
+                # ?????????????
                 try:
                     if hasattr(client, 'close'):
                         await client.close()
@@ -243,7 +240,28 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 except Exception as cleanup_error:
                     logger.warning(f"Failed to close current client for remote service {name}: {cleanup_error}")
 
-                # 通知生命周期管理器连接失败
+                # ????????????????????
+                failure_reason = None
+                try:
+                    status_code = getattr(getattr(e, 'response', None), 'status_code', None)
+                    if status_code in (401, 403):
+                        failure_reason = 'auth_failed'
+                    else:
+                        lower_msg = error_msg.lower()
+                        if any(word in lower_msg for word in ['unauthorized', 'forbidden', 'invalid token', 'invalid api key']):
+                            failure_reason = 'auth_failed'
+                except Exception:
+                    pass
+                try:
+                    metadata = self.registry.get_service_metadata(agent_id, name)
+                    if metadata:
+                        metadata.failure_reason = failure_reason
+                        metadata.error_message = error_msg
+                        self.registry.set_service_metadata(agent_id, name, metadata)
+                except Exception:
+                    pass
+
+                # ?????????????
                 await self.lifecycle_manager.handle_health_check_result(
                     agent_id=agent_id,
                     service_name=name,
@@ -258,8 +276,8 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             error_msg = str(e)
             logger.error(f"Error connecting remote service {name}: {error_msg}")
 
-            # 🔧 修复：清理资源，避免资源泄漏
-            # 清理客户端缓存
+            #  ??????????????
+            # ???????
             if name in self.clients:
                 try:
                     cached_client = self.clients[name]
@@ -270,7 +288,28 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 except Exception as cleanup_error:
                     logger.error(f"Failed to cleanup client cache for remote service {name} after outer exception: {cleanup_error}")
 
-            # 通知生命周期管理器连接失败
+            # ??????????????????????????
+            failure_reason = None
+            try:
+                status_code = getattr(getattr(e, 'response', None), 'status_code', None)
+                if status_code in (401, 403):
+                    failure_reason = 'auth_failed'
+                else:
+                    lower_msg = error_msg.lower()
+                    if any(word in lower_msg for word in ['unauthorized', 'forbidden', 'invalid token', 'invalid api key']):
+                        failure_reason = 'auth_failed'
+            except Exception:
+                pass
+            try:
+                metadata = self.registry.get_service_metadata(agent_id, name)
+                if metadata:
+                    metadata.failure_reason = failure_reason
+                    metadata.error_message = error_msg
+                    self.registry.set_service_metadata(agent_id, name, metadata)
+            except Exception:
+                pass
+
+            # ?????????????
             await self.lifecycle_manager.handle_health_check_result(
                 agent_id=agent_id,
                 service_name=name,
@@ -283,34 +322,24 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
 
     async def _update_service_cache(self, agent_id: str, service_name: str, client: Client, tools: List[Any], service_config: Dict[str, Any]):
         """
-        更新服务缓存（工具定义、映射关系等）
+        ??????????????????
 
         Args:
             agent_id: Agent ID
-            service_name: 服务名称
-            client: FastMCP客户端
-            tools: 工具列表
-            service_config: 服务配置
+            service_name: ????
+            client: FastMCP???
+            tools: ????
+            service_config: ????
         """
         try:
-            # 🔧 优雅修复：智能清理缓存，保留Agent-Client映射
-            existing_session = self.registry.get_session(agent_id, service_name)
-            if existing_session:
-                # 服务已存在，只清理工具缓存，保留Agent-Client映射
-                logger.debug(f"🔧 [CACHE_UPDATE] 服务 {service_name} 已存在，执行智能清理")
-                self.registry.clear_service_tools_only(agent_id, service_name)
-            else:
-                # 新服务，不需要清理任何缓存
-                logger.debug(f"🔧 [CACHE_UPDATE] 服务 {service_name} 是新服务，跳过清理")
-
-            # 处理工具定义（复用register_json_services的逻辑）
+            # ?????????register_json_services????
             processed_tools = []
             for tool in tools:
                 try:
                     original_tool_name = tool.name
                     display_name = self._generate_display_name(original_tool_name, service_name)
 
-                    # 处理参数
+                    # ????
                     parameters = {}
                     if hasattr(tool, 'inputSchema') and tool.inputSchema:
                         if hasattr(tool.inputSchema, 'model_dump'):
@@ -318,7 +347,7 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                         elif isinstance(tool.inputSchema, dict):
                             parameters = tool.inputSchema
 
-                    # 构建工具定义
+                    # ??????
                     tool_def = {
                         "type": "function",
                         "function": {
@@ -336,37 +365,84 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                     logger.error(f"Failed to process tool {tool.name}: {e}")
                     continue
 
-            # 🔧 优雅修复：添加到Registry缓存，保留现有映射关系
-            self.registry.add_service(
-                agent_id=agent_id,
-                name=service_name,
-                session=client,
-                tools=processed_tools,
-                preserve_mappings=True  # 保留现有的Agent-Client映射
-            )
+            # ?? per-agent ????????????????????
+            locks = getattr(self, 'store', None)
+            agent_locks = getattr(locks, 'agent_locks', None) if locks else None
+            if agent_locks is None:
+                logger.warning("AgentLocks not available; proceeding without per-agent lock for cache update")
+                #  ????????????
+                existing_session = self.registry.get_session(agent_id, service_name)
+                if existing_session:
+                    logger.debug(f" [CACHE_UPDATE] ?? {service_name} ??????????")
+                    self.registry.clear_service_tools_only(agent_id, service_name)
+                else:
+                    logger.debug(f" [CACHE_UPDATE] ?? {service_name} ?????????")
 
-            # 标记长连接服务
-            if self._is_long_lived_service(service_config):
-                self.registry.mark_as_long_lived(agent_id, service_name)
+                # Use a stable per-service session handle (not a live client)
+                session_handle = existing_session if existing_session is not None else object()
+                self.registry.add_service(
+                    agent_id=agent_id,
+                    name=service_name,
+                    session=session_handle,
+                    tools=processed_tools,
+                    service_config=service_config,
+                    state=ServiceConnectionState.HEALTHY,
+                    preserve_mappings=True
+                )
 
-            # 🔧 重要：注册客户端到 Agent 客户端缓存
-            client_id = self.registry.get_service_client_id(agent_id, service_name)
-            if client_id:
-                self.registry.add_agent_client_mapping(agent_id, client_id)
-                logger.debug(f"🔧 [CLIENT_REGISTER] 注册客户端 {client_id} 到 Agent {agent_id}")
+                if self._is_long_lived_service(service_config):
+                    self.registry.mark_as_long_lived(agent_id, service_name)
+
+                client_id = self.registry.get_service_client_id(agent_id, service_name)
+                if client_id:
+                    self.registry.add_agent_client_mapping(agent_id, client_id)
+                    logger.debug(f" [CLIENT_REGISTER] ????? {client_id} ? Agent {agent_id}")
+                else:
+                    logger.warning(f" [CLIENT_REGISTER] ?????? {service_name} ? Client ID")
             else:
-                logger.warning(f"🔧 [CLIENT_REGISTER] 无法获取服务 {service_name} 的 Client ID")
+                async with agent_locks.write(agent_id):
+                    #  ??????????????Agent-Client??
+                    existing_session = self.registry.get_session(agent_id, service_name)
+                    if existing_session:
+                        logger.debug(f" [CACHE_UPDATE] ?? {service_name} ??????????")
+                        self.registry.clear_service_tools_only(agent_id, service_name)
+                    else:
+                        logger.debug(f" [CACHE_UPDATE] ?? {service_name} ?????????")
 
-            # 通知生命周期管理器连接成功
+                    # ???Registry??????????????????
+                    session_handle = existing_session if existing_session is not None else object()
+                    self.registry.add_service(
+                        agent_id=agent_id,
+                        name=service_name,
+                        session=session_handle,
+                        tools=processed_tools,
+                        service_config=service_config,
+                        state=ServiceConnectionState.HEALTHY,
+                        preserve_mappings=True
+                    )
+
+                    # ???????
+                    if self._is_long_lived_service(service_config):
+                        self.registry.mark_as_long_lived(agent_id, service_name)
+
+                    # ?????? Agent ?????
+                    client_id = self.registry.get_service_client_id(agent_id, service_name)
+                    if client_id:
+                        self.registry.add_agent_client_mapping(agent_id, client_id)
+                        logger.debug(f" [CLIENT_REGISTER] ????? {client_id} ? Agent {agent_id}")
+                    else:
+                        logger.warning(f" [CLIENT_REGISTER] ?????? {service_name} ? Client ID")
+
+            # ?????????????
             await self.lifecycle_manager.handle_health_check_result(
                 agent_id=agent_id,
                 service_name=service_name,
                 success=True,
-                response_time=0.0,  # 连接时间，可以后续优化
+                response_time=0.0,  # ???????????
                 error_message=None
             )
 
-            # 将服务加入内容监控（用于运行期工具变化的兜底刷新）
+            # ?????????????????????????
             try:
                 if hasattr(self, 'content_manager') and self.content_manager:
                     self.content_manager.add_service_for_monitoring(agent_id, service_name)
@@ -376,24 +452,33 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
 
             logger.info(f"Updated cache for service '{service_name}' with {len(processed_tools)} tools for agent '{agent_id}'")
 
+            # A+B+D: ???????????????????????
+            try:
+                gid = self.client_manager.global_agent_store_id
+                if hasattr(self.registry, 'tools_changed'):
+                    self.registry.tools_changed(gid, aggressive=True)
+                logger.debug(f"[SNAPSHOT] connection: tools_changed after cache update service={service_name} agent={agent_id}")
+            except Exception as e:
+                logger.warning(f"[SNAPSHOT] tools_changed failed after cache update: {e}")
+
         except Exception as e:
             logger.error(f"Failed to update service cache for '{service_name}': {e}")
 
     def _is_long_lived_service(self, service_config: Dict[str, Any]) -> bool:
         """
-        判断是否为长连接服务
+        ??????????
 
         Args:
-            service_config: 服务配置
+            service_config: ????
 
         Returns:
-            是否为长连接服务
+            ????????
         """
-        # STDIO服务默认是长连接（keep_alive=True）
+        # STDIO?????????keep_alive=True?
         if "command" in service_config:
             return service_config.get("keep_alive", True)
 
-        # HTTP服务通常也是长连接
+        # HTTP?????????
         if "url" in service_config:
             return True
 
@@ -401,14 +486,14 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
 
     def _generate_display_name(self, original_tool_name: str, service_name: str) -> str:
         """
-        生成用户友好的工具显示名称
+        ?????????????
 
         Args:
-            original_tool_name: 原始工具名称
-            service_name: 服务名称
+            original_tool_name: ??????
+            service_name: ????
 
         Returns:
-            用户友好的显示名称
+            ?????????
         """
         try:
             from mcpstore.core.registry.tool_resolver import ToolNameResolver
@@ -416,14 +501,14 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             return resolver.create_user_friendly_name(service_name, original_tool_name)
         except Exception as e:
             logger.warning(f"Failed to generate display name for {original_tool_name}: {e}")
-            # 回退到简单格式
+            # ???????
             return f"{service_name}_{original_tool_name}"
 
     async def disconnect_service(self, url_or_name: str) -> bool:
-        """从配置中移除服务并更新global_agent_store"""
+        """???????????global_agent_store"""
         logger.info(f"Removing service: {url_or_name}")
 
-        # 查找要移除的服务名
+        # ?????????
         name_to_remove = None
         for name, server in self.global_agent_store_config.get("mcpServers", {}).items():
             if name == url_or_name or server.get("url") == url_or_name:
@@ -431,31 +516,31 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
                 break
 
         if name_to_remove:
-            # 从global_agent_store_config中移除
+            # ?global_agent_store_config???
             if name_to_remove in self.global_agent_store_config["mcpServers"]:
                 del self.global_agent_store_config["mcpServers"][name_to_remove]
 
-            # 从配置文件中移除
+            # ????????
             ok = self.mcp_config.remove_service(name_to_remove)
             if not ok:
                 logger.warning(f"Failed to remove service {name_to_remove} from configuration file")
 
-            # 从registry中移除
+            # ?registry???
             self.registry.remove_service(name_to_remove)
 
-            # 重新创建global_agent_store
+            # ????global_agent_store
             if self.global_agent_store_config.get("mcpServers"):
                 self.global_agent_store = Client(self.global_agent_store_config)
 
-                # 更新所有agent_clients
+                # ????agent_clients
                 for agent_id in list(self.agent_clients.keys()):
                     self.agent_clients[agent_id] = Client(self.global_agent_store_config)
                     logger.info(f"Updated client for agent {agent_id} after removing service")
 
             else:
-                # 如果没有服务了，清除global_agent_store
+                # ??????????global_agent_store
                 self.global_agent_store = None
-                # 清除所有agent_clients
+                # ????agent_clients
                 self.agent_clients.clear()
 
             return True
@@ -464,42 +549,42 @@ class ServiceConnectionMixin(HealthMonitoringMixin):
             return False
 
     async def refresh_services(self):
-        """手动刷新所有服务连接（重新加载mcp.json）"""
-        # 🔧 修复：使用统一同步管理器进行同步
+        """???????????????mcp.json?"""
+        #  ????????????????
         if hasattr(self, 'sync_manager') and self.sync_manager:
             await self.sync_manager.sync_global_agent_store_from_mcp_json()
         else:
             logger.warning("Sync manager not available, cannot refresh services")
 
     async def refresh_service_content(self, service_name: str, agent_id: str = None) -> bool:
-        """手动刷新指定服务的内容（工具、资源、提示词）"""
+        """??????????????????????"""
         agent_key = agent_id or self.client_manager.global_agent_store_id
         return await self.content_manager.force_update_service_content(agent_key, service_name)
 
     async def is_service_healthy(self, name: str, client_id: Optional[str] = None) -> bool:
         """
-        检查服务是否健康（增强版本，支持分级健康状态和智能超时）
+        ??????????????????
 
         Args:
-            name: 服务名
-            client_id: 可选的客户端ID，用于多客户端环境
+            name: ???
+            client_id: ??????ID?????????
 
         Returns:
-            bool: 服务是否健康（True表示healthy/warning/slow，False表示unhealthy）
+            bool: True ?????? HEALTHY/WARNING ??
         """
-        result = await self.check_service_health_detailed(name, client_id)
-        # 🆕 使用统一的健康状态判断逻辑
-        return HealthStatusBridge.is_health_status_positive(result.status)
+        agent_key = client_id or self.client_manager.global_agent_store_id
+        state = self.registry.get_service_state(agent_key, name)
+        return state in (ServiceConnectionState.HEALTHY, ServiceConnectionState.WARNING)
 
     def _normalize_service_config(self, service_config: Dict[str, Any]) -> Dict[str, Any]:
-        """规范化服务配置，确保包含必要的字段"""
+        """?????????????????"""
         if not service_config:
             return service_config
 
-        # 创建配置副本
+        # ??????
         normalized = service_config.copy()
 
-        # 自动推断transport类型（如果未指定）
+        # ????transport?????????
         if "url" in normalized and "transport" not in normalized:
             url = normalized["url"]
             if "/sse" in url.lower():
