@@ -3,11 +3,11 @@ MCPOrchestrator Service Management Module
 Service management module - contains service registration, management and information retrieval
 """
 
-import asyncio
 import logging
-from typing import Dict, List, Any, Optional, Tuple
+from typing import Dict, List, Any, Optional
 
 from fastmcp import Client
+
 from mcpstore.core.models.service import ServiceConnectionState
 
 logger = logging.getLogger(__name__)
@@ -15,6 +15,77 @@ logger = logging.getLogger(__name__)
 class ServiceManagementMixin:
     """Service management mixin class"""
 
+    async def tools_snapshot(self, agent_id: Optional[str] = None) -> List[Any]:
+        """Public API: read immutable snapshot bundle and project agent view (A+B+D).
+
+        - Always read global tools from the registry's current snapshot bundle.
+        - If agent_id provided, project the global services to agent-local names using
+          the mapping snapshot included in the bundle.
+        - No waiting/retry. Pure read and projection.
+        """
+        try:
+            bundle = self.registry.get_tools_snapshot_bundle()
+            # 若 bundle 不存在或被标记为脏，则触发重建
+            if (not bundle) or getattr(self.registry, 'is_tools_snapshot_dirty', lambda: False)():
+                reason = 'none' if not bundle else 'dirty'
+                logger.debug(f"[SNAPSHOT] tools_snapshot: trigger rebuild (reason={reason})")
+                bundle = self.registry.rebuild_tools_snapshot(self.client_manager.global_agent_store_id)
+            else:
+                meta = bundle.get("meta", {}) if isinstance(bundle, dict) else {}
+                logger.debug(f"[SNAPSHOT] tools_snapshot: using bundle version={meta.get('version')}")
+
+            tools_section = bundle.get("tools", {})
+            mappings = bundle.get("mappings", {})
+            services_index: Dict[str, List[Dict[str, Any]]] = tools_section.get("services", {})
+
+            # Flatten global tools
+            flat_global: List[Dict[str, Any]] = []
+            for svc, items in services_index.items():
+                if not items:
+                    continue
+                for it in items:
+                    # ensure service_name is global name here
+                    entry = dict(it)
+                    entry["service_name"] = svc
+                    flat_global.append(entry)
+
+            if not agent_id:
+                return flat_global
+
+            # Agent projection: global -> local service names
+            agent_map = mappings.get("agent_to_global", {}).get(agent_id, {})
+            # Build reverse map for this agent only: global -> local
+            reverse_map: Dict[str, str] = {g: l for (l, g) in agent_map.items()}
+
+            projected: List[Dict[str, Any]] = []
+            for item in flat_global:
+                gsvc = item.get("service_name")
+                lsvc = reverse_map.get(gsvc)
+                if not lsvc:
+                    # Strict projection: skip services without mapping for this agent
+                    continue
+                new_item = dict(item)
+                new_item["service_name"] = lsvc
+                # Rewrite tool name to use local service prefix to keep name/service consistent
+                name = new_item.get("name")
+                if isinstance(name, str):
+                    if name.startswith(f"{gsvc}_"):
+                        # service_tool -> replace global service with local
+                        suffix = name[len(gsvc) + 1:]
+                        new_item["name"] = f"{lsvc}_{suffix}"
+                    elif name.startswith(f"{gsvc}__"):
+                        # legacy double-underscore format: normalize to single underscore
+                        suffix = name[len(gsvc) + 2:]
+                        new_item["name"] = f"{lsvc}_{suffix}"
+                projected.append(new_item)
+
+            logger.debug(f"[SNAPSHOT] tools_snapshot: return_count={len(projected)} (agent_view)")
+            return projected
+
+        except Exception as e:
+            logger.error(f"Failed to get tools snapshot: {e}")
+            return []
+
     async def register_agent_client(self, agent_id: str, config: Dict[str, Any] = None) -> Client:
         """
         Register a new client instance for agent
@@ -32,7 +103,7 @@ class ServiceManagementMixin:
 
         # 存储agent_client
         self.agent_clients[agent_id] = agent_client
-        logger.info(f"Registered agent client for {agent_id}")
+        logger.debug(f"Registered agent client for {agent_id}")
 
         return agent_client
 
@@ -64,10 +135,10 @@ class ServiceManagementMixin:
 
         for name in services:
             try:
-                # 使用生命周期管理器获取服务状态
-                service_state = self.lifecycle_manager.get_service_state(agent_id, name)
+                # 🆕 事件驱动架构：直接从 registry 获取服务状态
+                service_state = self.registry.get_service_state(agent_id, name)
 
-                # 🔧 修复：新服务（状态为None）也应该被处理
+                #  修复：新服务（状态为None）也应该被处理
                 if service_state is None:
                     healthy_services.append(name)
                     logger.debug(f"Service {name} has no state (new service), included in processable list")
@@ -88,14 +159,14 @@ class ServiceManagementMixin:
                 logger.warning(f"Failed to check service state for {name}: {e}")
                 continue
 
-        logger.info(f"Filtered {len(healthy_services)} healthy services from {len(services)} total services")
+        logger.debug(f"Filtered {len(healthy_services)} healthy services from {len(services)} total")
         return healthy_services
 
     async def start_global_agent_store(self, config: Dict[str, Any]):
         """启动 global_agent_store 的 async with 生命周期，注册服务和工具（仅健康服务）"""
         # 获取健康的服务列表
         healthy_services = await self.filter_healthy_services(list(config.get("mcpServers", {}).keys()))
-        
+
         # 创建一个新的配置，只包含健康的服务
         healthy_config = {
             "mcpServers": {
@@ -103,120 +174,18 @@ class ServiceManagementMixin:
                 for name in healthy_services
             }
         }
-        
-        # 使用健康的配置注册服务
-        await self.register_json_services(healthy_config, client_id="global_agent_store")
-        # global_agent_store专属管理逻辑可在这里补充（如缓存、生命周期等）
 
-    async def register_json_services(self, config: Dict[str, Any], client_id: str = None, agent_id: str = None):
-        """
-        @deprecated 此方法已废弃，请使用统一的add_service方法
-
-        ⚠️ 警告：此方法已被统一注册架构替代，建议使用：
-        - store.for_store().add_service_async() - Store级别注册
-        - store.for_agent(agent_id).add_service_async() - Agent级别注册
-
-        注册JSON配置中的服务（可用于global_agent_store或普通client）
-        """
-
-
-        # agent_id 兼容
-        agent_key = agent_id or client_id or self.client_manager.global_agent_store_id
+        # 使用统一注册路径（替代过时的 register_json_services）
         try:
-            # 获取健康的服务列表
-            healthy_services = await self.filter_healthy_services(list(config.get("mcpServers", {}).keys()), client_id)
-            
-            # 创建一个新的配置，只包含健康的服务
-            healthy_config = {
-                "mcpServers": {
-                    name: config["mcpServers"][name]
-                    for name in healthy_services
-                }
-            }
-            
-            if not healthy_config["mcpServers"]:
-                logger.warning(f"No healthy services found for client {agent_key}")
-                return
-            
-            # 使用ConfigProcessor处理配置
-            from mcpstore.core.config_processor import ConfigProcessor
-            processed_config = ConfigProcessor.process_user_config_for_fastmcp(healthy_config)
-            
-            # 创建客户端
-            client = Client(processed_config)
-            
-            # 连接并获取工具
-            async with client:
-                # 获取所有工具
-                tools = await client.list_tools()
-                
-                # 按服务分组工具
-                tools_by_service = {}
-                for tool in tools:
-                    # 从工具名推断服务名（这里需要更智能的逻辑）
-                    service_name = self._infer_service_from_tool(tool.name, list(healthy_config["mcpServers"].keys()))
-                    if service_name not in tools_by_service:
-                        tools_by_service[service_name] = []
-                    tools_by_service[service_name].append(tool)
-                
-                # 注册每个服务的工具
-                for service_name, service_tools in tools_by_service.items():
-                    try:
-                        # 处理工具定义
-                        processed_tools = []
-                        for tool in service_tools:
-                            try:
-                                original_tool_name = tool.name
-                                display_name = self._generate_display_name(original_tool_name, service_name)
-                                
-                                # 处理参数
-                                parameters = {}
-                                if hasattr(tool, 'inputSchema') and tool.inputSchema:
-                                    if hasattr(tool.inputSchema, 'model_dump'):
-                                        parameters = tool.inputSchema.model_dump()
-                                    elif isinstance(tool.inputSchema, dict):
-                                        parameters = tool.inputSchema
-                                
-                                # 构建工具定义
-                                tool_def = {
-                                    "type": "function",
-                                    "function": {
-                                        "name": original_tool_name,
-                                        "display_name": display_name,
-                                        "description": tool.description,
-                                        "parameters": parameters,
-                                        "service_name": service_name
-                                    }
-                                }
-                                
-                                processed_tools.append((display_name, tool_def))
-                                
-                            except Exception as e:
-                                logger.error(f"Failed to process tool {tool.name}: {e}")
-                                continue
-                        
-                        # 添加到Registry
-                        self.registry.add_service(agent_key, service_name, client, processed_tools)
-                        
-                        # 标记长连接服务
-                        service_config = healthy_config["mcpServers"].get(service_name, {})
-                        if self._is_long_lived_service(service_config):
-                            self.registry.mark_as_long_lived(agent_key, service_name)
-                        
-                        logger.info(f"Registered service '{service_name}' with {len(processed_tools)} tools for client '{agent_key}'")
-                        
-                    except Exception as e:
-                        logger.error(f"Failed to register service {service_name}: {e}")
-                        continue
-                
-                # 保存客户端配置到ClientManager
-                self.client_manager.save_client_config(agent_key, processed_config)
-                
-                logger.info(f"Successfully registered {len(tools_by_service)} services with {len(tools)} total tools for client '{agent_key}'")
-                
+            if self._context_factory:
+                context = self._context_factory()
+                await context.add_service_async(healthy_config)
+            else:
+                logger.warning("Orchestrator context factory not available; skipping auto registration pipeline")
         except Exception as e:
-            logger.error(f"Failed to register JSON services for client {agent_key}: {e}")
-            raise
+            logger.error(f"Failed to register healthy services via add_service_async: {e}")
+
+    # register_json_services 已移除（Deprecated）
 
     def _infer_service_from_tool(self, tool_name: str, service_names: List[str]) -> str:
         """从工具名推断服务名"""
@@ -224,7 +193,7 @@ class ServiceManagementMixin:
         for service_name in service_names:
             if service_name.lower() in tool_name.lower():
                 return service_name
-        
+
         # 如果没有匹配，返回第一个服务名（假设单服务配置）
         return service_names[0] if service_names else "unknown_service"
 
@@ -239,7 +208,7 @@ class ServiceManagementMixin:
     async def remove_service(self, service_name: str, agent_id: str = None):
         """移除服务并处理生命周期状态"""
         try:
-            # 🔧 修复：更安全的agent_id处理
+            #  修复：更安全的agent_id处理
             if agent_id is None:
                 if not hasattr(self.client_manager, 'global_agent_store_id'):
                     logger.error("No agent_id provided and global_agent_store_id not available")
@@ -250,8 +219,8 @@ class ServiceManagementMixin:
                 agent_key = agent_id
                 logger.debug(f"Using provided agent_id: {agent_key}")
 
-            # 🔧 修复：检查服务是否存在于生命周期管理器中
-            current_state = self.lifecycle_manager.get_service_state(agent_key, service_name)
+            # 🆕 事件驱动架构：直接从 registry 检查服务状态
+            current_state = self.registry.get_service_state(agent_key, service_name)
             if current_state is None:
                 logger.warning(f"Service {service_name} not found in lifecycle manager for agent {agent_key}")
                 # 检查是否存在于注册表中
@@ -259,14 +228,14 @@ class ServiceManagementMixin:
                     logger.warning(f"Service {service_name} not found in registry for agent {agent_key}, skipping removal")
                     return
                 else:
-                    logger.info(f"Service {service_name} found in registry but not in lifecycle manager, proceeding with cleanup")
+                    logger.debug(f"Service {service_name} found in registry but not in lifecycle, cleaning up")
 
             if current_state:
-                logger.info(f"Removing service {service_name} from agent {agent_key} (current state: {current_state.value})")
+                logger.debug(f"Removing service {service_name} from agent {agent_key} (state: {current_state.value})")
             else:
-                logger.info(f"Removing service {service_name} from agent {agent_key} (no lifecycle state)")
+                logger.debug(f"Removing service {service_name} from agent {agent_key} (no lifecycle state)")
 
-            # 🔧 修复：安全地调用各个组件的移除方法
+            #  修复：安全地调用各个组件的移除方法
             try:
                 # 通知生命周期管理器开始优雅断连（如果服务存在于生命周期管理器中）
                 if current_state:
@@ -281,8 +250,21 @@ class ServiceManagementMixin:
                 logger.warning(f"Error removing from content monitoring: {e}")
 
             try:
-                # 从注册表中移除服务
+                # 从注册表中移除服务（内部将触发 tools_changed）
                 self.registry.remove_service(agent_key, service_name)
+
+                # 取消健康监控（若存在）
+                try:
+                    if self.container:
+                        hm = getattr(self.container, 'health_monitor', None)
+                        if hm and hasattr(hm, '_health_check_tasks'):
+                            task_key = (agent_key, service_name)
+                            task = hm._health_check_tasks.pop(task_key, None)
+                            if task and not task.done():
+                                task.cancel()
+                            logger.debug(f"[HEALTH] Unwatched removed service: {service_name} (agent={agent_key})")
+                except Exception as e:
+                    logger.debug(f"[HEALTH] Unwatch removed service failed: {e}")
             except Exception as e:
                 logger.warning(f"Error removing from registry: {e}")
 
@@ -292,7 +274,15 @@ class ServiceManagementMixin:
             except Exception as e:
                 logger.warning(f"Error removing lifecycle data: {e}")
 
-            logger.info(f"Service {service_name} removal completed for agent {agent_key}")
+            # A+B+D: 变更后触发统一快照更新（强一致）
+            try:
+                gid = self.client_manager.global_agent_store_id
+                if hasattr(self.registry, 'tools_changed'):
+                    self.registry.tools_changed(gid, aggressive=True)
+            except Exception as e:
+                logger.warning(f"[SNAPSHOT] tools_changed failed after removal: {e}")
+
+            logger.debug(f"Service removal completed: {service_name} from agent {agent_key}")
 
         except Exception as e:
             logger.error(f"Error removing service {service_name}: {e}")
@@ -320,19 +310,9 @@ class ServiceManagementMixin:
         agent_key = agent_id or self.client_manager.global_agent_store_id
         return self.registry.get_service_details(agent_key, service_name)
 
-    def update_service_health(self, service_name: str, agent_id: str = None):
-        """
-        ⚠️ 已废弃：此方法已被ServiceLifecycleManager替代
-        """
-        logger.debug(f"update_service_health is deprecated for service: {service_name}")
-        pass
-
-    def get_last_heartbeat(self, service_name: str, agent_id: str = None):
-        """
-        ⚠️ 已废弃：此方法已被ServiceLifecycleManager替代
-        """
-        logger.debug(f"get_last_heartbeat is deprecated for service: {service_name}")
-        return None
+    # 🆕 事件驱动架构：以下方法已被废弃并删除
+    # - update_service_health: 已被 ServiceLifecycleManager 替代
+    # - get_last_heartbeat: 已被 ServiceLifecycleManager 替代
 
     def has_service(self, service_name: str, agent_id: str = None):
         agent_key = agent_id or self.client_manager.global_agent_store_id
@@ -352,7 +332,7 @@ class ServiceManagementMixin:
         try:
             agent_key = agent_id or self.client_manager.global_agent_store_id
 
-            logger.info(f"🔄 [RESTART_SERVICE] Starting restart for service '{service_name}' (agent: {agent_key})")
+            logger.debug(f"Restarting service {service_name} for agent {agent_key}")
 
             # 检查服务是否存在
             if not self.registry.has_service(agent_key, service_name):
@@ -362,12 +342,12 @@ class ServiceManagementMixin:
             # 获取服务元数据
             metadata = self.registry.get_service_metadata(agent_key, service_name)
             if not metadata:
-                logger.error(f"❌ [RESTART_SERVICE] No metadata found for service '{service_name}'")
+                logger.error(f" [RESTART_SERVICE] No metadata found for service '{service_name}'")
                 return False
 
             # 重置服务状态为 INITIALIZING
             self.registry.set_service_state(agent_key, service_name, ServiceConnectionState.INITIALIZING)
-            logger.debug(f"🔄 [RESTART_SERVICE] Set state to INITIALIZING for '{service_name}'")
+            logger.debug(f" [RESTART_SERVICE] Set state to INITIALIZING for '{service_name}'")
 
             # 重置元数据
             from datetime import datetime
@@ -380,18 +360,60 @@ class ServiceManagementMixin:
 
             # 更新元数据到注册表
             self.registry.set_service_metadata(agent_key, service_name, metadata)
-            logger.debug(f"🔄 [RESTART_SERVICE] Reset metadata for '{service_name}'")
+            logger.debug(f" [RESTART_SERVICE] Reset metadata for '{service_name}'")
 
-            # 如果有生命周期管理器，触发初始化
-            if hasattr(self, 'lifecycle_manager') and self.lifecycle_manager:
-                init_success = self.lifecycle_manager.initialize_service(agent_key, service_name, metadata.service_config)
-                logger.debug(f"🔄 [RESTART_SERVICE] Triggered lifecycle initialization for '{service_name}': {init_success}")
+            # 事件驱动架构：直接发布 ServiceInitialized，由 ConnectionManager 接手连接
+            try:
+                from mcpstore.core.events.service_events import ServiceInitialized
+                # 优先使用 container.event_bus；否则回退到 orchestrator.event_bus
+                bus = None
+                bus_source = None
+                if self.container:
+                    bus = getattr(self.container, 'event_bus', None)
+                    bus_source = 'container.event_bus' if bus else None
+                if not bus:
+                    bus = getattr(self, 'event_bus', None)
+                    bus_source = bus_source or ('orchestrator.event_bus' if bus else None)
 
-            logger.info(f"✅ [RESTART_SERVICE] Successfully restarted service '{service_name}'")
+                # Diagnostics: compare bus identities
+                try:
+                    container_bus = getattr(self.container, 'event_bus', None) if self.container else None
+                    orchestrator_bus = getattr(self, 'event_bus', None)
+                    logger.debug(
+                        f" [RESTART_SERVICE] bus_diag chosen={hex(id(bus)) if bus else 'None'} "
+                        f"container={hex(id(container_bus)) if container_bus else 'None'} "
+                        f"orchestrator={hex(id(orchestrator_bus)) if orchestrator_bus else 'None'}"
+                    )
+                except Exception as e:
+                    logger.debug(f" [RESTART_SERVICE] bus_diag error: {e}")
+
+                if bus:
+                    initialized_event = ServiceInitialized(
+                        agent_id=agent_key,
+                        service_name=service_name,
+                        initial_state="initializing"
+                    )
+                    await bus.publish(initialized_event, wait=True)
+                    logger.debug(f" [RESTART_SERVICE] Published ServiceInitialized for '{service_name}' via {bus_source}")
+
+                    # 追加一次性健康检查请求，确保初始化后快速收敛（不必等待周期心跳）
+                    from mcpstore.core.events.service_events import HealthCheckRequested
+                    health_check_event = HealthCheckRequested(
+                        agent_id=agent_key,
+                        service_name=service_name
+                    )
+                    await bus.publish(health_check_event, wait=True)
+                    logger.debug(f" [RESTART_SERVICE] Published HealthCheckRequested for '{service_name}' via {bus_source}")
+                else:
+                    logger.warning(" [RESTART_SERVICE] EventBus not available (neither orchestrator nor store.container); cannot publish ServiceInitialized")
+            except Exception as pub_err:
+                logger.warning(f" [RESTART_SERVICE] Failed to publish ServiceInitialized for '{service_name}': {pub_err}")
+
+            logger.info(f"Service restarted successfully: {service_name}")
             return True
 
         except Exception as e:
-            logger.error(f"❌ [RESTART_SERVICE] Failed to restart service '{service_name}': {e}")
+            logger.error(f" [RESTART_SERVICE] Failed to restart service '{service_name}': {e}")
             return False
 
     def _generate_display_name(self, original_tool_name: str, service_name: str) -> str:
@@ -492,7 +514,7 @@ class ServiceManagementMixin:
                 status_response["consecutive_failures"] = 0
                 status_response["state_entered_time"] = None
 
-            logger.debug(f"Retrieved cached status for service {service_name}: {status_response['status']}")
+            logger.info(f"[GET_STATUS] service='{service_name}' agent_key='{agent_key}' status='{status_response.get('status')}' healthy={status_response.get('healthy')} last_check={status_response.get('last_check')} resp_time={status_response.get('response_time')} cf={status_response.get('consecutive_failures')}")
             return status_response
 
         except Exception as e:
