@@ -501,7 +501,7 @@ class ToolNameResolver:
         """
         转换为FastMCP标准格式的工具名称
 
-        🔧 重要发现：
+         重要发现：
         - MCPStore内部：工具名称带前缀 "mcpstore-demo-weather_get_current_weather"
         - FastMCP原生：工具名称不带前缀 "get_current_weather"
         - 我们需要返回FastMCP原生期望的格式！
@@ -566,82 +566,55 @@ class FastMCPToolExecutor:
     ) -> 'CallToolResult':
         """
         执行工具（严格按照 FastMCP 官网标准）
-        
+
+        仅使用 FastMCP 官方客户端的 call_tool 返回对象，不做任何自定义“等价对象”封装，
+        不再回退到 call_tool_mcp 进行字段映射，确保结果形态与官方一致。
+
         Args:
-            client: FastMCP 客户端实例
+            client: FastMCP 客户端实例（必须实现 call_tool）
             tool_name: 工具名称（FastMCP 原始名称）
             arguments: 工具参数
             timeout: 超时时间（秒）
             progress_handler: 进度处理器
             raise_on_error: 是否在错误时抛出异常
-            
+
         Returns:
             CallToolResult: FastMCP 标准结果对象
         """
         arguments = arguments or {}
         timeout = timeout or self.default_timeout
-        
+
         try:
-            # 根据实际的 FastMCP 2.7.1 版本调用
-            call_kwargs = {
-                "name": tool_name,
-                "arguments": arguments
-            }
+            if not hasattr(client, 'call_tool'):
+                raise RuntimeError("FastMCP client does not support call_tool; please use a compatible FastMCP client")
 
-            # 添加支持的参数
-            if timeout is not None:
-                call_kwargs["timeout"] = timeout
-            if progress_handler is not None:
-                call_kwargs["progress_handler"] = progress_handler
-
-            # FastMCP 2.7.1 的 call_tool 返回 list[TextContent|ImageContent|EmbeddedResource]
-            # 而不是 CallToolResult，所以我们需要使用 call_tool_mcp 来获取完整结果
-            if hasattr(client, 'call_tool_mcp'):
-                # 使用 call_tool_mcp 获取 CallToolResult
-                logger.debug(f"Using call_tool_mcp for complete result")
-                result = await client.call_tool_mcp(**call_kwargs)
-
-                # 手动处理 raise_on_error 逻辑
-                if hasattr(result, 'is_error') and result.is_error and raise_on_error:
-                    error_msg = "Tool execution failed"
-                    if hasattr(result, 'content') and result.content:
-                        for content in result.content:
-                            if hasattr(content, 'text'):
-                                error_msg = content.text
-                                break
-                    raise Exception(error_msg)
-
-                return result
-            else:
-                # 回退到普通的 call_tool
-                logger.debug(f"Using standard call_tool")
-                content_list = await client.call_tool(**call_kwargs)
-
-                # 将内容列表包装成类似 CallToolResult 的对象
-                from types import SimpleNamespace
-                result = SimpleNamespace(
-                    content=content_list,
-                    is_error=False,
-                    data=None,
-                    structured_content=None
-                )
-
-                return result
+            logger.debug("Using client.call_tool (FastMCP official) for result")
+            result = await client.call_tool(
+                name=tool_name,
+                arguments=arguments,
+                timeout=timeout,
+                progress_handler=progress_handler,
+                raise_on_error=raise_on_error,
+            )
+            return result
 
         except Exception as e:
             logger.error(f"Tool '{tool_name}' execution failed: {e}")
             if raise_on_error:
                 raise
-            else:
-                # 返回错误结果
+            # 返回与 FastMCP 形态兼容的错误信号：直接向上传播异常已被关闭时，按空 content + is_error=True 返回
+            try:
                 from types import SimpleNamespace
                 return SimpleNamespace(
                     content=[],
-                    is_error=True,
-                    data=None,
                     structured_content=None,
-                    error=str(e)
+                    data=None,
+                    is_error=True,
+                    error=str(e),
                 )
+            except Exception:
+                # 最后兜底：仍然抛出原始异常
+                raise
     
     def extract_result_data(self, result: 'CallToolResult') -> Any:
         """
