@@ -14,7 +14,8 @@
 """
 
 import logging
-from typing import Dict, Any, Optional, List, Tuple
+from typing import Dict, Any
+
 from mcpstore.core.context.agent_service_mapper import AgentServiceMapper
 
 logger = logging.getLogger(__name__)
@@ -65,10 +66,10 @@ class BidirectionalSyncManager:
                 # 从 Store 中删除服务
                 await self._delete_store_service(global_name)
             
-            logger.info(f"✅ [BIDIRECTIONAL_SYNC] Agent → Store 同步完成: {sync_key}")
+            logger.info(f" [BIDIRECTIONAL_SYNC] Agent → Store 同步完成: {sync_key}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] Agent → Store 同步失败 {sync_key}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] Agent → Store 同步失败 {sync_key}: {e}")
         finally:
             self._syncing_services.discard(sync_key)
     
@@ -107,10 +108,10 @@ class BidirectionalSyncManager:
                 # 从 Agent 中删除服务
                 await self._delete_agent_service(agent_id, local_name)
             
-            logger.info(f"✅ [BIDIRECTIONAL_SYNC] Store → Agent 同步完成: {sync_key}")
+            logger.info(f" [BIDIRECTIONAL_SYNC] Store → Agent 同步完成: {sync_key}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] Store → Agent 同步失败 {sync_key}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] Store → Agent 同步失败 {sync_key}: {e}")
         finally:
             self._syncing_services.discard(sync_key)
     
@@ -133,7 +134,7 @@ class BidirectionalSyncManager:
                 await self.sync_agent_to_store(agent_id, service_name, new_config, "update")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 服务更新同步失败 {agent_id}:{service_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 服务更新同步失败 {agent_id}:{service_name}: {e}")
     
     async def handle_service_deletion_with_sync(self, agent_id: str, service_name: str):
         """
@@ -153,7 +154,7 @@ class BidirectionalSyncManager:
                 await self.sync_agent_to_store(agent_id, service_name, {}, "delete")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 服务删除同步失败 {agent_id}:{service_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 服务删除同步失败 {agent_id}:{service_name}: {e}")
     
     # === 内部同步实现方法 ===
     
@@ -168,21 +169,16 @@ class BidirectionalSyncManager:
                     new_config
                 )
             
-            # 2. 更新 mcp.json
-            current_mcp_config = self.store.config.load_config()
-            if "mcpServers" not in current_mcp_config:
-                current_mcp_config["mcpServers"] = {}
-            
-            current_mcp_config["mcpServers"][global_name] = new_config
-            success = self.store.config.save_config(current_mcp_config)
+            # 2. 更新 mcp.json（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self.store._unified_config.add_service_config(global_name, new_config)
             
             if success:
-                logger.debug(f"✅ [BIDIRECTIONAL_SYNC] Store 配置更新成功: {global_name}")
+                logger.debug(f" [BIDIRECTIONAL_SYNC] Store 配置更新成功: {global_name}，缓存已同步")
             else:
-                logger.error(f"❌ [BIDIRECTIONAL_SYNC] Store 配置更新失败: {global_name}")
+                logger.error(f" [BIDIRECTIONAL_SYNC] Store 配置更新失败: {global_name}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 更新 Store 服务配置失败 {global_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 更新 Store 服务配置失败 {global_name}: {e}")
             raise
     
     async def _update_agent_service_config(self, agent_id: str, local_name: str, new_config: Dict[str, Any]):
@@ -192,10 +188,10 @@ class BidirectionalSyncManager:
             if hasattr(self.store.registry, 'update_service_config'):
                 self.store.registry.update_service_config(agent_id, local_name, new_config)
             
-            logger.debug(f"✅ [BIDIRECTIONAL_SYNC] Agent 配置更新成功: {agent_id}:{local_name}")
+            logger.debug(f" [BIDIRECTIONAL_SYNC] Agent 配置更新成功: {agent_id}:{local_name}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 更新 Agent 服务配置失败 {agent_id}:{local_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 更新 Agent 服务配置失败 {agent_id}:{local_name}: {e}")
             raise
     
     async def _delete_store_service(self, global_name: str):
@@ -207,19 +203,16 @@ class BidirectionalSyncManager:
                 global_name
             )
             
-            # 2. 从 mcp.json 中删除
-            current_mcp_config = self.store.config.load_config()
-            if "mcpServers" in current_mcp_config and global_name in current_mcp_config["mcpServers"]:
-                del current_mcp_config["mcpServers"][global_name]
-                success = self.store.config.save_config(current_mcp_config)
-                
-                if success:
-                    logger.debug(f"✅ [BIDIRECTIONAL_SYNC] Store 服务删除成功: {global_name}")
-                else:
-                    logger.error(f"❌ [BIDIRECTIONAL_SYNC] Store 服务删除失败: {global_name}")
+            # 2. 从 mcp.json 中删除（使用 UnifiedConfigManager 自动刷新缓存）
+            success = self.store._unified_config.remove_service_config(global_name)
+            
+            if success:
+                logger.debug(f" [BIDIRECTIONAL_SYNC] Store 服务删除成功: {global_name}，缓存已同步")
+            else:
+                logger.error(f" [BIDIRECTIONAL_SYNC] Store 服务删除失败: {global_name}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 删除 Store 服务失败 {global_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 删除 Store 服务失败 {global_name}: {e}")
             raise
     
     async def _delete_agent_service(self, agent_id: str, local_name: str):
@@ -231,10 +224,10 @@ class BidirectionalSyncManager:
             # 移除映射关系
             self.store.registry.remove_agent_service_mapping(agent_id, local_name)
             
-            logger.debug(f"✅ [BIDIRECTIONAL_SYNC] Agent 服务删除成功: {agent_id}:{local_name}")
+            logger.debug(f" [BIDIRECTIONAL_SYNC] Agent 服务删除成功: {agent_id}:{local_name}")
             
         except Exception as e:
-            logger.error(f"❌ [BIDIRECTIONAL_SYNC] 删除 Agent 服务失败 {agent_id}:{local_name}: {e}")
+            logger.error(f" [BIDIRECTIONAL_SYNC] 删除 Agent 服务失败 {agent_id}:{local_name}: {e}")
             raise
     
     def get_sync_status(self) -> Dict[str, Any]:
