@@ -14,6 +14,7 @@
 import asyncio
 import logging
 from typing import List, Tuple, Set, Optional, Dict
+
 from mcpstore.core.models.service import ServiceConnectionState
 
 logger = logging.getLogger(__name__)
@@ -85,7 +86,7 @@ class SharedClientStateSyncManager:
                 logger.debug(f" [STATE_SYNC] No sync needed for client_id {client_id}")
                 
         except Exception as e:
-            logger.error(f"❌ [STATE_SYNC] Failed to sync state for {agent_id}:{service_name}: {e}")
+            logger.error(f" [STATE_SYNC] Failed to sync state for {agent_id}:{service_name}: {e}")
         finally:
             self._syncing.discard(sync_key)
     
@@ -106,7 +107,7 @@ class SharedClientStateSyncManager:
                 if mapped_client_id == client_id:
                     services.append((agent_id, service_name))
         
-        logger.debug(f"🔍 [STATE_SYNC] Found {len(services)} services with client_id {client_id}: {services}")
+        logger.debug(f" [STATE_SYNC] Found {len(services)} services with client_id {client_id}: {services}")
         return services
     
     def _set_state_directly(self, agent_id: str, service_name: str, state: ServiceConnectionState):
@@ -161,7 +162,7 @@ class SharedClientStateSyncManager:
             }
             
         except Exception as e:
-            logger.error(f"❌ [STATE_SYNC] Failed to get shared services info for {agent_id}:{service_name}: {e}")
+            logger.error(f" [STATE_SYNC] Failed to get shared services info for {agent_id}:{service_name}: {e}")
             return None
     
     async def atomic_state_update(self, agent_id: str, service_name: str, new_state: ServiceConnectionState):
@@ -202,7 +203,7 @@ class SharedClientStateSyncManager:
                 logger.info(f" [ATOMIC_SYNC] Atomic update completed: {updated_count} services updated to {new_state.value} for client_id {client_id}")
                 
             except Exception as e:
-                logger.error(f"❌ [ATOMIC_SYNC] Failed atomic state update for {agent_id}:{service_name}: {e}")
+                logger.error(f" [ATOMIC_SYNC] Failed atomic state update for {agent_id}:{service_name}: {e}")
                 raise
     
     def validate_state_consistency(self, client_id: str) -> Dict[str, any]:
@@ -219,7 +220,7 @@ class SharedClientStateSyncManager:
             - inconsistent_services: List 状态不一致的服务
         """
         try:
-            logger.debug(f"🔍 [STATE_VALIDATION] Validating state consistency for client_id: {client_id}")
+            logger.debug(f" [STATE_VALIDATION] Validating state consistency for client_id: {client_id}")
             
             # 查找所有使用该 client_id 的服务
             shared_services = self._find_all_services_with_client_id(client_id)
@@ -271,14 +272,14 @@ class SharedClientStateSyncManager:
             }
             
             if is_consistent:
-                logger.info(f"✅ [STATE_VALIDATION] State consistency validated for client_id {client_id}: ALL CONSISTENT")
+                logger.info(f" [STATE_VALIDATION] State consistency validated for client_id {client_id}: ALL CONSISTENT")
             else:
                 logger.warning(f"⚠️ [STATE_VALIDATION] State inconsistency detected for client_id {client_id}: {len(inconsistent_services)} services inconsistent")
             
             return result
             
         except Exception as e:
-            logger.error(f"❌ [STATE_VALIDATION] Failed to validate state consistency for client_id {client_id}: {e}")
+            logger.error(f" [STATE_VALIDATION] Failed to validate state consistency for client_id {client_id}: {e}")
             return {
                 "consistent": False,
                 "services": [],
@@ -317,10 +318,10 @@ class SharedClientStateSyncManager:
                     else:
                         logger.debug(f" [BATCH_SYNC] Skipped {agent_id}:{service_name}: already {target_state.value}")
                 
-                logger.info(f"✅ [BATCH_SYNC] Batch sync completed: {updated_count}/{len(shared_services)} services updated for client_id {client_id}")
+                logger.info(f" [BATCH_SYNC] Batch sync completed: {updated_count}/{len(shared_services)} services updated for client_id {client_id}")
                 
             except Exception as e:
-                logger.error(f"❌ [BATCH_SYNC] Failed batch sync for client_id {client_id}: {e}")
+                logger.error(f" [BATCH_SYNC] Failed batch sync for client_id {client_id}: {e}")
                 raise
     
     def _set_state_directly(self, agent_id: str, service_name: str, new_state: ServiceConnectionState):
@@ -345,5 +346,5 @@ class SharedClientStateSyncManager:
                 logger.warning(f"⚠️ [DIRECT_SET] Agent {agent_id} not found in service_states")
                 
         except Exception as e:
-            logger.error(f"❌ [DIRECT_SET] Failed to set state directly for {agent_id}:{service_name}: {e}")
+            logger.error(f" [DIRECT_SET] Failed to set state directly for {agent_id}:{service_name}: {e}")
             raise
