@@ -16,21 +16,22 @@ import asyncio
 import logging
 import os
 import time
-from pathlib import Path
-from typing import Dict, Set, Optional, Any
-from watchdog.observers import Observer
-from watchdog.events import FileSystemEventHandler
+from typing import Dict, Any
+
+# 强制使用内置 watchdog（不再可选）
+from mcpstore.utils.watchdog.observers import Observer
+from mcpstore.utils.watchdog.events import FileSystemEventHandler
 
 logger = logging.getLogger(__name__)
 
 
 class MCPFileHandler(FileSystemEventHandler):
     """MCP configuration file change handler"""
-    
+
     def __init__(self, sync_manager):
         self.sync_manager = sync_manager
         self.mcp_filename = os.path.basename(sync_manager.mcp_json_path)
-        
+
     def on_modified(self, event):
         """File modification event handling"""
         if event.is_directory:
@@ -74,8 +75,8 @@ class UnifiedMCPSyncManager:
         self.debounce_delay = 1.0  # 防抖延迟（秒）
         self.sync_task = None
         self.last_change_time = None
-        self.last_sync_time = None  # 🔧 新增：记录上次同步时间
-        self.min_sync_interval = 5.0  # 🔧 新增：最小同步间隔（秒）
+        self.last_sync_time = None  #  新增：记录上次同步时间
+        self.min_sync_interval = 5.0  #  新增：最小同步间隔（秒）
         self.is_running = False
         
         logger.info(f"UnifiedMCPSyncManager initialized for: {self.mcp_json_path}")
@@ -85,20 +86,20 @@ class UnifiedMCPSyncManager:
         if self.is_running:
             logger.warning("Sync manager is already running")
             return
-            
+
         try:
             logger.info("Starting unified MCP sync manager...")
-            
+
             # 启动文件监听
             await self._start_file_watcher()
 
-            # 🔧 执行启动时同步（始终启用）
+            #  执行启动时同步（始终启用）
             logger.info("Executing initial sync from mcp.json")
             await self.sync_global_agent_store_from_mcp_json()
 
             self.is_running = True
             logger.info("Unified MCP sync manager started successfully")
-            
+
         except Exception as e:
             logger.error(f"Failed to start sync manager: {e}")
             await self.stop()
@@ -136,18 +137,18 @@ class UnifiedMCPSyncManager:
                     import json
                     json.dump({"mcpServers": {}}, f, indent=2)
                 logger.info(f"Created empty MCP config file: {self.mcp_json_path}")
-            
+
             # 创建文件监听器
             self.file_observer = Observer()
             handler = MCPFileHandler(self)
-            
+
             # 监听mcp.json所在目录
             watch_dir = os.path.dirname(self.mcp_json_path)
             self.file_observer.schedule(handler, watch_dir, recursive=False)
             self.file_observer.start()
-            
+
             logger.info(f"File watcher started for directory: {watch_dir}")
-            
+
         except Exception as e:
             logger.error(f"Failed to start file watcher: {e}")
             raise
@@ -187,7 +188,7 @@ class UnifiedMCPSyncManager:
         """从mcp.json同步global_agent_store（核心方法）"""
         async with self.sync_lock:
             try:
-                # 🔧 新增：检查同步频率，避免过度同步
+                #  新增：检查同步频率，避免过度同步
                 import time
                 current_time = time.time()
 
@@ -206,7 +207,7 @@ class UnifiedMCPSyncManager:
                 # 执行同步
                 results = await self._sync_global_agent_store_services(services)
 
-                # 🔧 新增：记录同步时间
+                #  新增：记录同步时间
                 self.last_sync_time = current_time
 
                 logger.info(f"Global agent store sync completed: {results}")
@@ -312,7 +313,7 @@ class UnifiedMCPSyncManager:
             else:
                 logger.debug("No services need to be registered to Registry")
 
-            # 4. 🔧 新增：触发缓存到文件的异步持久化
+            # 4.  新增：触发缓存到文件的异步持久化
             if services_to_register:
                 await self._trigger_cache_persistence()
             
@@ -382,10 +383,9 @@ class UnifiedMCPSyncManager:
                     continue
                 try:
                     if hasattr(self.orchestrator, 'store') and self.orchestrator.store:
-                        # Use existing add_service_async with explicit mcpServers shape
+                        # Use existing add_service_async with explicit mcpServers shape (no extra kwargs)
                         await self.orchestrator.store.for_store().add_service_async(
-                            config={"mcpServers": {service_name: config}},
-                            source="auto_startup"
+                            config={"mcpServers": {service_name: config}}
                         )
                     else:
                         # Update mcp.json directly then let lifecycle initialize
@@ -426,7 +426,7 @@ class UnifiedMCPSyncManager:
                 logger.error("Registry not available")
                 return False
 
-            # 🔧 修复：检查是否已存在该服务的client_id，避免重复生成
+            #  修复：检查是否已存在该服务的client_id，避免重复生成
             existing_client_id = self._find_existing_client_id_for_service(agent_id, service_name)
 
             if existing_client_id:
@@ -434,7 +434,7 @@ class UnifiedMCPSyncManager:
                 client_id = existing_client_id
                 logger.debug(f" 使用现有client_id: {service_name} -> {client_id}")
             else:
-                # 🔧 使用统一的ClientIDGenerator生成确定性client_id
+                #  使用统一的ClientIDGenerator生成确定性client_id
                 from mcpstore.core.utils.id_generator import ClientIDGenerator
                 
                 # UnifiedMCPSyncManager主要处理Store级别的服务，所以使用global_agent_store_id
@@ -491,7 +491,7 @@ class UnifiedMCPSyncManager:
             for client_id in client_ids:
                 client_config = registry.client_configs.get(client_id, {})
                 if service_name in client_config.get("mcpServers", {}):
-                    logger.debug(f"🔍 找到现有client_id: {service_name} -> {client_id}")
+                    logger.debug(f" 找到现有client_id: {service_name} -> {client_id}")
                     return client_id
 
             return None
